@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright (c) 2012 OpenStack Foundation.
 # All Rights Reserved.
 #
@@ -18,15 +16,17 @@
 import re
 
 import netaddr
+from oslo_log import log as logging
+from oslo_utils import uuidutils
+from six import iteritems
 
 from tacker.common import constants
 from tacker.common import exceptions as n_exc
-from tacker.openstack.common import log as logging
-from tacker.openstack.common import uuidutils
 
 
 LOG = logging.getLogger(__name__)
 
+ATTRIBUTES_TO_UPDATE = 'attributes_to_update'
 ATTR_NOT_SPECIFIED = object()
 # Defining a constant to avoid repeating string literal in several modules
 SHARED = 'shared'
@@ -392,7 +392,7 @@ def _validate_dict_item(key, key_validator, data):
     # TODO(salv-orlando): Structure of dict attributes should be improved
     # to avoid iterating over items
     val_func = val_params = None
-    for (k, v) in key_validator.iteritems():
+    for (k, v) in iteritems(key_validator):
         if k.startswith('type:'):
             # ask forgiveness, not permission
             try:
@@ -416,7 +416,7 @@ def _validate_dict(data, key_specs=None):
         return
 
     # Check whether all required keys are present
-    required_keys = [key for key, spec in key_specs.iteritems()
+    required_keys = [key for key, spec in iteritems(key_specs)
                      if spec.get('required')]
 
     if required_keys:
@@ -427,7 +427,7 @@ def _validate_dict(data, key_specs=None):
 
     # Perform validation and conversion of all values
     # according to the specifications.
-    for key, key_validator in [(k, v) for k, v in key_specs.iteritems()
+    for key, key_validator in [(k, v) for k, v in iteritems(key_specs)
                                if k in data]:
         msg = _validate_dict_item(key, key_validator, data)
         if msg:
@@ -518,7 +518,7 @@ def convert_kvp_list_to_dict(kvp_list):
         key, value = convert_kvp_str_to_list(kvp_str)
         kvp_map.setdefault(key, set())
         kvp_map[key].add(value)
-    return dict((x, list(y)) for x, y in kvp_map.iteritems())
+    return dict((x, list(y)) for x, y in iteritems(kvp_map))
 
 
 def convert_none_to_empty_list(value):
@@ -609,6 +609,8 @@ validators = {'type:dict': _validate_dict,
 
 RESOURCE_ATTRIBUTE_MAP = {}
 
+RESOURCE_FOREIGN_KEYS = {}
+
 PLURALS = {'extensions': 'extension'}
 EXT_NSES = {}
 
