@@ -17,10 +17,9 @@
 Tacker base exception handling.
 """
 
+from oslo_utils import excutils
 import six
 
-from tacker.openstack.common import excutils
-
 
 class TackerException(Exception):
     """Base Tacker Exception.
@@ -240,3 +239,21 @@ class DeviceIDNotOwnedByTenant(Conflict):
 
 class InvalidCIDR(BadRequest):
     message = _("Invalid CIDR %(input)s given as IP prefix")
+
+
+class MgmtDriverException(TackerException):
+    message = _("VNF configuration failed")
+
+
+class VnfPolicyNotFound(NotFound):
+    message = _("Policy %(policy)s does not exist for VNF %(vnf_id)s")
+
+
+class VnfPolicyActionInvalid(BadRequest):
+    message = _("Invalid action %(action)s for policy %(policy)s, "
+                "should be one of %(valid_acions)s")
+
+
+class VnfPolicyTypeInvalid(BadRequest):
+    message = _("Invalid type %(type)s for policy %(policy)s, "
+                "should be one of %(valid_types)s")
