@@ -32,14 +32,15 @@ import uuid
 
 from eventlet.green import subprocess
 import netaddr
+from oslo_concurrency import lockutils
 from oslo_config import cfg
+from oslo_log import log as logging
 from oslo_utils import importutils
+from six import iteritems
 from stevedore import driver
 
+from tacker._i18n import _LE
 from tacker.common import constants as q_const
-from tacker.i18n import _LE
-from tacker.openstack.common import lockutils
-from tacker.openstack.common import log as logging
 
 
 TIME_FORMAT = "%Y-%m-%dT%H:%M:%SZ"
@@ -211,7 +212,7 @@ def subprocess_popen(args, stdin=None, stdout=None, stderr=None, shell=False,
 
 
 def parse_mappings(mapping_list, unique_values=True):
-    """Parse a list of of mapping strings into a dictionary.
+    """Parse a list of mapping strings into a dictionary.
 
     :param mapping_list: a list of strings of the form '<key>:<value>'
     :param unique_values: values must be unique if True
@@ -251,16 +252,14 @@ def compare_elements(a, b):
 
     This method doesn't consider ordering
     """
-    if a is None:
-        a = []
-    if b is None:
-        b = []
+    a = a or []
+    b = b or []
     return set(a) == set(b)
 
 
 def dict2str(dic):
     return ','.join("%s=%s" % (key, val)
-                    for key, val in sorted(dic.iteritems()))
+                    for key, val in sorted(iteritems(dic)))
 
 
 def str2dict(string):
@@ -344,7 +343,7 @@ def change_memory_unit(mem, to):
     """
 
     mem = str(mem) + " MB" if str(mem).isdigit() else mem.upper()
-    for unit, value in MEM_UNITS.iteritems():
+    for unit, value in iteritems(MEM_UNITS):
         mem_arr = mem.split(unit)
         if len(mem_arr) < 2:
             continue
