@@ -1,8 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-#
 # Copyright 2013, 2014 Intel Corporation.
-# Copyright 2013, 2014 Isaku Yamahata <isaku.yamahata at intel com>
-#                                     <isaku.yamahata at gmail com>
 # All Rights Reserved.
 #
 #
@@ -20,20 +16,22 @@
 
 import uuid
 
+from oslo_log import log as logging
+from oslo_utils import timeutils
+
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.orm import exc as orm_exc
 
 from tacker.api.v1 import attributes
 from tacker import context as t_context
-from tacker.db import api as qdbapi
+from tacker.db.common_services import common_services_db
 from tacker.db import db_base
 from tacker.db import model_base
 from tacker.db import models_v1
+from tacker.db import types
 from tacker.extensions import vnfm
 from tacker import manager
-from tacker.openstack.common import log as logging
-from tacker.openstack.common import uuidutils
 from tacker.plugins.common import constants
 
 LOG = logging.getLogger(__name__)
@@ -41,17 +39,20 @@ _ACTIVE_UPDATE = (constants.ACTIVE, constants.PENDING_UPDATE)
 _ACTIVE_UPDATE_ERROR_DEAD = (
     constants.PENDING_CREATE, constants.ACTIVE, constants.PENDING_UPDATE,
     constants.ERROR, constants.DEAD)
+CREATE_STATES = (constants.PENDING_CREATE, constants.DEAD)
 
 
 ###########################################################################
 # db tables
 
-class DeviceTemplate(model_base.BASE, models_v1.HasId, models_v1.HasTenant):
-    """Represents template to create hosting device."""
+class VNFD(model_base.BASE, models_v1.HasId, models_v1.HasTenant,
+           models_v1.Audit):
+    """Represents VNFD to create VNF."""
 
+    __tablename__ = 'vnfd'
     # Descriptive name
-    name = sa.Column(sa.String(255))
-    description = sa.Column(sa.String(255))
+    name = sa.Column(sa.String(255), nullable=False)
+    description = sa.Column(sa.Text)
 
     # service type that this service vm provides.
     # At first phase, this includes only single service
@@ -65,7 +66,7 @@ class DeviceTemplate(model_base.BASE, models_v1.HasId, models_v1.HasTenant):
     mgmt_driver = sa.Column(sa.String(255))
 
     # (key, value) pair to spin up
-    attributes = orm.relationship('DeviceTemplateAttribute',
+    attributes = orm.relationship('VNFDAttribute',
                                   backref='template')
 
 
@@ -75,65 +76,69 @@ class ServiceType(model_base.BASE, models_v1.HasId, models_v1.HasTenant):
     Since a device may provide many services, This is one-to-many
     relationship.
     """
-    template_id = sa.Column(sa.String(36), sa.ForeignKey('devicetemplates.id'),
-                            nullable=False)
-    service_type = sa.Column(sa.String(255), nullable=False)
+    vnfd_id = sa.Column(types.Uuid, sa.ForeignKey('vnfd.id'),
+                        nullable=False)
+    service_type = sa.Column(sa.String(64), nullable=False)
 
 
-class DeviceTemplateAttribute(model_base.BASE, models_v1.HasId):
+class VNFDAttribute(model_base.BASE, models_v1.HasId):
     """Represents attributes necessary for spinning up VM in (key, value) pair
 
     key value pair is adopted for being agnostic to actuall manager of VMs
     like nova, heat or others. e.g. image-id, flavor-id for Nova.
     The interpretation is up to actual driver of hosting device.
     """
-    template_id = sa.Column(sa.String(36), sa.ForeignKey('devicetemplates.id'),
-                            nullable=False)
+
+    __tablename__ = 'vnfd_attribute'
+    vnfd_id = sa.Column(types.Uuid, sa.ForeignKey('vnfd.id'),
+                        nullable=False)
     key = sa.Column(sa.String(255), nullable=False)
     value = sa.Column(sa.TEXT(65535), nullable=True)
 
 
-class Device(model_base.BASE, models_v1.HasTenant):
+class VNF(model_base.BASE, models_v1.HasId, models_v1.HasTenant,
+          models_v1.Audit):
     """Represents devices that hosts services.
 
     Here the term, 'VM', is intentionally avoided because it can be
     VM or other container.
     """
-    id = sa.Column(sa.String(255),
-                   primary_key=True,
-                   default=uuidutils.generate_uuid)
 
-    template_id = sa.Column(sa.String(36), sa.ForeignKey('devicetemplates.id'))
-    template = orm.relationship('DeviceTemplate')
+    __tablename__ = 'vnf'
+    vnfd_id = sa.Column(types.Uuid, sa.ForeignKey('vnfd.id'))
+    vnfd = orm.relationship('VNFD')
 
-    name = sa.Column(sa.String(255), nullable=True)
-    description = sa.Column(sa.String(255), nullable=True)
+    name = sa.Column(sa.String(255), nullable=False)
+    description = sa.Column(sa.Text, nullable=True)
 
     # sufficient information to uniquely identify hosting device.
     # In case of service VM, it's UUID of nova VM.
-    instance_id = sa.Column(sa.String(255), nullable=True)
+    instance_id = sa.Column(sa.String(64), nullable=True)
 
     # For a management tool to talk to manage this hosting device.
     # opaque string.
     # e.g. (driver, mgmt_url) = (ssh, ip address), ...
     mgmt_url = sa.Column(sa.String(255), nullable=True)
-    attributes = orm.relationship("DeviceAttribute", backref="device")
+    attributes = orm.relationship("VNFAttribute", backref="device")
 
-    status = sa.Column(sa.String(255), nullable=False)
-    vim_id = sa.Column(sa.String(36), sa.ForeignKey('vims.id'), nullable=False)
-    placement_attr = sa.Column(sa.PickleType, nullable=True)
+    status = sa.Column(sa.String(64), nullable=False)
+    vim_id = sa.Column(types.Uuid, sa.ForeignKey('vims.id'), nullable=False)
+    placement_attr = sa.Column(types.Json, nullable=True)
     vim = orm.relationship('Vim')
+    error_reason = sa.Column(sa.Text, nullable=True)
 
 
-class DeviceAttribute(model_base.BASE, models_v1.HasId):
+class VNFAttribute(model_base.BASE, models_v1.HasId):
     """Represents kwargs necessary for spinning up VM in (key, value) pair.
 
     key value pair is adopted for being agnostic to actuall manager of VMs
     like nova, heat or others. e.g. image-id, flavor-id for Nova.
     The interpretation is up to actual driver of hosting device.
     """
-    device_id = sa.Column(sa.String(255), sa.ForeignKey('devices.id'),
-                          nullable=False)
+
+    __tablename__ = 'vnf_attribute'
+    vnf_id = sa.Column(types.Uuid, sa.ForeignKey('vnf.id'),
+                       nullable=False)
     key = sa.Column(sa.String(255), nullable=False)
     # json encoded value. example
     # "nic": [{"net-id": <net-uuid>}, {"port-id": <port-uuid>}]
@@ -151,18 +156,18 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
         return subnet['network_id']
 
     def __init__(self):
-        qdbapi.register_models()
         super(VNFMPluginDb, self).__init__()
+        self._cos_db_plg = common_services_db.CommonServicesPluginDb()
 
     def _get_resource(self, context, model, id):
         try:
             return self._get_by_id(context, model, id)
         except orm_exc.NoResultFound:
-            if issubclass(model, DeviceTemplate):
-                raise vnfm.DeviceTemplateNotFound(device_tempalte_id=id)
+            if issubclass(model, VNFD):
+                raise vnfm.DeviceTemplateNotFound(device_template_id=id)
             elif issubclass(model, ServiceType):
                 raise vnfm.ServiceTypeNotFound(service_type_id=id)
-            if issubclass(model, Device):
+            if issubclass(model, VNF):
                 raise vnfm.DeviceNotFound(device_id=id)
             else:
                 raise
@@ -182,7 +187,8 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
                 template.service_types)
         }
         key_list = ('id', 'tenant_id', 'name', 'description',
-                    'infra_driver', 'mgmt_driver')
+                    'infra_driver', 'mgmt_driver',
+                    'created_at', 'updated_at')
         res.update((key, template[key]) for key in key_list)
         return self._fields(res, fields)
 
@@ -194,12 +200,12 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
         LOG.debug(_('device_db attributes %s'), device_db.attributes)
         res = {
             'device_template':
-            self._make_template_dict(device_db.template),
+            self._make_template_dict(device_db.vnfd),
             'attributes': self._make_dev_attrs_dict(device_db.attributes),
         }
         key_list = ('id', 'tenant_id', 'name', 'description', 'instance_id',
-                    'vim_id', 'placement_attr', 'template_id', 'status',
-                    'mgmt_url')
+                    'vim_id', 'placement_attr', 'vnfd_id', 'status',
+                    'mgmt_url', 'error_reason', 'created_at', 'updated_at')
         res.update((key, device_db[key]) for key in key_list)
         return self._fields(res, fields)
 
@@ -235,7 +241,7 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
 
         with context.session.begin(subtransactions=True):
             template_id = str(uuid.uuid4())
-            template_db = DeviceTemplate(
+            template_db = VNFD(
                 id=template_id,
                 tenant_id=tenant_id,
                 name=template.get('name'),
@@ -244,9 +250,9 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
                 mgmt_driver=mgmt_driver)
             context.session.add(template_db)
             for (key, value) in template.get('attributes', {}).items():
-                attribute_db = DeviceTemplateAttribute(
+                attribute_db = VNFDAttribute(
                     id=str(uuid.uuid4()),
-                    template_id=template_id,
+                    vnfd_id=template_id,
                     key=key,
                     value=value)
                 context.session.add(attribute_db)
@@ -255,48 +261,76 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
                 service_type_db = ServiceType(
                     id=str(uuid.uuid4()),
                     tenant_id=tenant_id,
-                    template_id=template_id,
+                    vnfd_id=template_id,
                     service_type=service_type)
                 context.session.add(service_type_db)
 
         LOG.debug(_('template_db %(template_db)s %(attributes)s '),
                   {'template_db': template_db,
                    'attributes': template_db.attributes})
-        return self._make_template_dict(template_db)
+        vnfd_dict = self._make_template_dict(template_db)
+        LOG.debug(_('vnfd_dict %s'), vnfd_dict)
+        self._cos_db_plg.create_event(
+            context, res_id=vnfd_dict['id'],
+            res_type=constants.RES_TYPE_VNFD,
+            res_state=constants.RES_EVT_VNFD_NA_STATE,
+            evt_type=constants.RES_EVT_CREATE,
+            tstamp=vnfd_dict[constants.RES_EVT_CREATED_FLD])
+        return vnfd_dict
 
     def update_device_template(self, context, device_template_id,
                                device_template):
         with context.session.begin(subtransactions=True):
-            template_db = self._get_resource(context, DeviceTemplate,
+            template_db = self._get_resource(context, VNFD,
                                              device_template_id)
             template_db.update(device_template['device_template'])
-        return self._make_template_dict(template_db)
+            template_db.update({'updated_at': timeutils.utcnow()})
+            vnfd_dict = self._make_template_dict(template_db)
+            self._cos_db_plg.create_event(
+                context, res_id=vnfd_dict['id'],
+                res_type=constants.RES_TYPE_VNFD,
+                res_state=constants.RES_EVT_VNFD_NA_STATE,
+                evt_type=constants.RES_EVT_UPDATE,
+                tstamp=vnfd_dict[constants.RES_EVT_UPDATED_FLD])
+        return vnfd_dict
 
-    def delete_device_template(self, context, device_template_id):
+    def delete_device_template(self,
+                               context,
+                               device_template_id,
+                               soft_delete=True):
         with context.session.begin(subtransactions=True):
             # TODO(yamahata): race. prevent from newly inserting hosting device
             #                 that refers to this template
-            devices_db = context.session.query(Device).filter_by(
-                template_id=device_template_id).first()
-            if devices_db is not None:
+            devices_db = context.session.query(VNF).filter_by(
+                vnfd_id=device_template_id).first()
+            if devices_db is not None and devices_db.deleted_at is None:
                 raise vnfm.DeviceTemplateInUse(
                     device_template_id=device_template_id)
 
-            context.session.query(ServiceType).filter_by(
-                template_id=device_template_id).delete()
-            context.session.query(DeviceTemplateAttribute).filter_by(
-                template_id=device_template_id).delete()
-            template_db = self._get_resource(context, DeviceTemplate,
+            template_db = self._get_resource(context, VNFD,
                                              device_template_id)
-            context.session.delete(template_db)
+            if soft_delete:
+                template_db.update({'deleted_at': timeutils.utcnow()})
+                self._cos_db_plg.create_event(
+                    context, res_id=template_db['id'],
+                    res_type=constants.RES_TYPE_VNFD,
+                    res_state=constants.RES_EVT_VNFD_NA_STATE,
+                    evt_type=constants.RES_EVT_DELETE,
+                    tstamp=template_db[constants.RES_EVT_DELETED_FLD])
+            else:
+                context.session.query(ServiceType).filter_by(
+                    vnfd_id=device_template_id).delete()
+                context.session.query(VNFDAttribute).filter_by(
+                    vnfd_id=device_template_id).delete()
+                context.session.delete(template_db)
 
     def get_device_template(self, context, device_template_id, fields=None):
-        template_db = self._get_resource(context, DeviceTemplate,
+        template_db = self._get_resource(context, VNFD,
                                          device_template_id)
         return self._make_template_dict(template_db)
 
     def get_device_templates(self, context, filters, fields=None):
-        return self._get_collection(context, DeviceTemplate,
+        return self._get_collection(context, VNFD,
                                     self._make_template_dict,
                                     filters=filters, fields=fields)
 
@@ -306,19 +340,19 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
         LOG.debug(_('required_attributes %s'), required_attributes)
         with context.session.begin(subtransactions=True):
             query = (
-                context.session.query(DeviceTemplate).
+                context.session.query(VNFD).
                 filter(
                     sa.exists().
                     where(sa.and_(
-                        DeviceTemplate.id == ServiceType.template_id,
+                        VNFD.id == ServiceType.vnfd_id,
                         ServiceType.service_type == service_type))))
             for key in required_attributes:
                 query = query.filter(
                     sa.exists().
                     where(sa.and_(
-                        DeviceTemplate.id ==
-                        DeviceTemplateAttribute.template_id,
-                        DeviceTemplateAttribute.key == key)))
+                        VNFD.id ==
+                        VNFDAttribute.vnfd_id,
+                        VNFDAttribute.key == key)))
             LOG.debug(_('statements %s'), query)
             template_db = query.first()
             if template_db:
@@ -326,14 +360,14 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
 
     def _device_attribute_update_or_create(
             self, context, device_id, key, value):
-        arg = (self._model_query(context, DeviceAttribute).
-               filter(DeviceAttribute.device_id == device_id).
-               filter(DeviceAttribute.key == key).first())
+        arg = (self._model_query(context, VNFAttribute).
+               filter(VNFAttribute.vnf_id == device_id).
+               filter(VNFAttribute.key == key).first())
         if arg:
             arg.value = value
         else:
-            arg = DeviceAttribute(
-                id=str(uuid.uuid4()), device_id=device_id,
+            arg = VNFAttribute(
+                id=str(uuid.uuid4()), vnf_id=device_id,
                 key=key, value=value)
             context.session.add(arg)
 
@@ -343,29 +377,36 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
         tenant_id = self._get_tenant_id_for_create(context, device)
         template_id = device['template_id']
         name = device.get('name')
-        device_id = device.get('id') or str(uuid.uuid4())
+        device_id = str(uuid.uuid4())
         attributes = device.get('attributes', {})
         vim_id = device.get('vim_id')
         placement_attr = device.get('placement_attr', {})
         with context.session.begin(subtransactions=True):
-            template_db = self._get_resource(context, DeviceTemplate,
+            template_db = self._get_resource(context, VNFD,
                                              template_id)
-            device_db = Device(id=device_id,
-                               tenant_id=tenant_id,
-                               name=name,
-                               description=template_db.description,
-                               instance_id=None,
-                               template_id=template_id,
-                               vim_id=vim_id,
-                               placement_attr=placement_attr,
-                               status=constants.PENDING_CREATE)
+            device_db = VNF(id=device_id,
+                            tenant_id=tenant_id,
+                            name=name,
+                            description=template_db.description,
+                            instance_id=None,
+                            vnfd_id=template_id,
+                            vim_id=vim_id,
+                            placement_attr=placement_attr,
+                            status=constants.PENDING_CREATE,
+                            error_reason=None)
             context.session.add(device_db)
             for key, value in attributes.items():
-                    arg = DeviceAttribute(
-                        id=str(uuid.uuid4()), device_id=device_id,
+                    arg = VNFAttribute(
+                        id=str(uuid.uuid4()), vnf_id=device_id,
                         key=key, value=value)
                     context.session.add(arg)
-
+        self._cos_db_plg.create_event(
+            context, res_id=device_id,
+            res_type=constants.RES_TYPE_VNF,
+            res_state=constants.PENDING_CREATE,
+            evt_type=constants.RES_EVT_CREATE,
+            tstamp=timeutils.utcnow(),
+            details="VNF UUID assigned")
         return self._make_device_dict(device_db)
 
     # called internally, not by REST API
@@ -374,9 +415,9 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
                             mgmt_url, device_dict):
         LOG.debug(_('device_dict %s'), device_dict)
         with context.session.begin(subtransactions=True):
-            query = (self._model_query(context, Device).
-                     filter(Device.id == device_id).
-                     filter(Device.status == constants.PENDING_CREATE).
+            query = (self._model_query(context, VNF).
+                     filter(VNF.id == device_id).
+                     filter(VNF.status.in_(CREATE_STATES)).
                      one())
             query.update({'instance_id': instance_id, 'mgmt_url': mgmt_url})
             if instance_id is None or device_dict['status'] == constants.ERROR:
@@ -387,20 +428,34 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
                 if 'vim_auth' not in key:
                     self._device_attribute_update_or_create(context, device_id,
                                                             key, value)
+        evt_details = ("Infra Instance ID created: %s and "
+                       "Mgmt URL set: %s") % (instance_id, mgmt_url)
+        self._cos_db_plg.create_event(
+            context, res_id=device_dict['id'],
+            res_type=constants.RES_TYPE_VNF,
+            res_state=device_dict['status'],
+            evt_type=constants.RES_EVT_CREATE,
+            tstamp=timeutils.utcnow(), details=evt_details)
 
     def _create_device_status(self, context, device_id, new_status):
         with context.session.begin(subtransactions=True):
-            (self._model_query(context, Device).
-                filter(Device.id == device_id).
-                filter(Device.status == constants.PENDING_CREATE).
-                update({'status': new_status}))
+            query = (self._model_query(context, VNF).
+                     filter(VNF.id == device_id).
+                     filter(VNF.status.in_(CREATE_STATES)).one())
+            query.update({'status': new_status})
+            self._cos_db_plg.create_event(
+                context, res_id=device_id,
+                res_type=constants.RES_TYPE_VNF,
+                res_state=new_status,
+                evt_type=constants.RES_EVT_CREATE,
+                tstamp=timeutils.utcnow(), details="VNF status updated")
 
     def _get_device_db(self, context, device_id, current_statuses, new_status):
         try:
             device_db = (
-                self._model_query(context, Device).
-                filter(Device.id == device_id).
-                filter(Device.status.in_(current_statuses)).
+                self._model_query(context, VNF).
+                filter(VNF.id == device_id).
+                filter(VNF.status.in_(current_statuses)).
                 with_lockmode('update').one())
         except orm_exc.NoResultFound:
             raise vnfm.DeviceNotFound(device_id=device_id)
@@ -409,51 +464,102 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
         device_db.update({'status': new_status})
         return device_db
 
+    def _update_vnf_scaling_status(self,
+                                   context,
+                                   policy,
+                                   previous_statuses,
+                                   status,
+                                   mgmt_url=None):
+        with context.session.begin(subtransactions=True):
+            device_db = self._get_device_db(
+                context, policy['vnf']['id'], previous_statuses, status)
+            if mgmt_url:
+                device_db.update({'mgmt_url': mgmt_url})
+        return self._make_device_dict(device_db)
+
     def _update_device_pre(self, context, device_id):
         with context.session.begin(subtransactions=True):
             device_db = self._get_device_db(
                 context, device_id, _ACTIVE_UPDATE, constants.PENDING_UPDATE)
-        return self._make_device_dict(device_db)
+        updated_device_dict = self._make_device_dict(device_db)
+        self._cos_db_plg.create_event(
+            context, res_id=device_id,
+            res_type=constants.RES_TYPE_VNF,
+            res_state=updated_device_dict['status'],
+            evt_type=constants.RES_EVT_UPDATE,
+            tstamp=timeutils.utcnow())
+        return updated_device_dict
 
     def _update_device_post(self, context, device_id, new_status,
                             new_device_dict=None):
         with context.session.begin(subtransactions=True):
-            (self._model_query(context, Device).
-             filter(Device.id == device_id).
-             filter(Device.status == constants.PENDING_UPDATE).
-             update({'status': new_status}))
+            (self._model_query(context, VNF).
+             filter(VNF.id == device_id).
+             filter(VNF.status == constants.PENDING_UPDATE).
+             update({'status': new_status,
+                     'updated_at': timeutils.utcnow()}))
 
             dev_attrs = new_device_dict.get('attributes', {})
-            (context.session.query(DeviceAttribute).
-             filter(DeviceAttribute.device_id == device_id).
-             filter(~DeviceAttribute.key.in_(dev_attrs.keys())).
+            (context.session.query(VNFAttribute).
+             filter(VNFAttribute.vnf_id == device_id).
+             filter(~VNFAttribute.key.in_(dev_attrs.keys())).
              delete(synchronize_session='fetch'))
 
             for (key, value) in dev_attrs.items():
                 if 'vim_auth' not in key:
                     self._device_attribute_update_or_create(context, device_id,
                                                         key, value)
+        self._cos_db_plg.create_event(
+            context, res_id=device_id,
+            res_type=constants.RES_TYPE_VNF,
+            res_state=new_device_dict['status'],
+            evt_type=constants.RES_EVT_UPDATE,
+            tstamp=new_device_dict[constants.RES_EVT_UPDATED_FLD])
 
     def _delete_device_pre(self, context, device_id):
         with context.session.begin(subtransactions=True):
             device_db = self._get_device_db(
                 context, device_id, _ACTIVE_UPDATE_ERROR_DEAD,
                 constants.PENDING_DELETE)
+        deleted_device_db = self._make_device_dict(device_db)
+        self._cos_db_plg.create_event(
+            context, res_id=device_id,
+            res_type=constants.RES_TYPE_VNF,
+            res_state=deleted_device_db['status'],
+            evt_type=constants.RES_EVT_DELETE,
+            tstamp=timeutils.utcnow(), details="VNF delete initiated")
+        return deleted_device_db
 
-        return self._make_device_dict(device_db)
-
-    def _delete_device_post(self, context, device_id, error):
+    def _delete_device_post(self, context, device_id, error, soft_delete=True):
         with context.session.begin(subtransactions=True):
             query = (
-                self._model_query(context, Device).
-                filter(Device.id == device_id).
-                filter(Device.status == constants.PENDING_DELETE))
+                self._model_query(context, VNF).
+                filter(VNF.id == device_id).
+                filter(VNF.status == constants.PENDING_DELETE))
             if error:
                 query.update({'status': constants.ERROR})
+                self._cos_db_plg.create_event(
+                    context, res_id=device_id,
+                    res_type=constants.RES_TYPE_VNF,
+                    res_state=constants.ERROR,
+                    evt_type=constants.RES_EVT_DELETE,
+                    tstamp=timeutils.utcnow(),
+                    details="VNF Delete ERROR")
             else:
-                (self._model_query(context, DeviceAttribute).
-                 filter(DeviceAttribute.device_id == device_id).delete())
-                query.delete()
+                if soft_delete:
+                    deleted_time_stamp = timeutils.utcnow()
+                    query.update({'deleted_at': deleted_time_stamp})
+                    self._cos_db_plg.create_event(
+                        context, res_id=device_id,
+                        res_type=constants.RES_TYPE_VNF,
+                        res_state=constants.PENDING_DELETE,
+                        evt_type=constants.RES_EVT_DELETE,
+                        tstamp=deleted_time_stamp,
+                        details="VNF Delete Complete")
+                else:
+                    (self._model_query(context, VNFAttribute).
+                     filter(VNFAttribute.vnf_id == device_id).delete())
+                    query.delete()
 
     # reference implementation. needs to be overrided by subclass
     def create_device(self, context, device):
@@ -479,32 +585,38 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
         return device_dict
 
     # reference implementation. needs to be overrided by subclass
-    def delete_device(self, context, device_id):
+    def delete_device(self, context, device_id, soft_delete=True):
         self._delete_device_pre(context, device_id)
         # start actual deletion of hosting device.
         # Waiting for completion of deletion should be done backgroundly
         # by another thread if it takes a while.
-        self._delete_device_post(context, device_id, False)
+        self._delete_device_post(context,
+                                 device_id,
+                                 False,
+                                 soft_delete=soft_delete)
 
     def get_device(self, context, device_id, fields=None):
-        device_db = self._get_resource(context, Device, device_id)
+        device_db = self._get_resource(context, VNF, device_id)
         return self._make_device_dict(device_db, fields)
 
     def get_devices(self, context, filters=None, fields=None):
-        devices = self._get_collection(context, Device, self._make_device_dict,
-                                       filters=filters, fields=fields)
-        # Ugly hack to mask internaly used record
-        return [device for device in devices
-                if uuidutils.is_uuid_like(device['id'])]
+        return self._get_collection(context, VNF, self._make_device_dict,
+                                    filters=filters, fields=fields)
+
+    def set_device_error_status_reason(self, context, device_id, new_reason):
+        with context.session.begin(subtransactions=True):
+            (self._model_query(context, VNF).
+                filter(VNF.id == device_id).
+                update({'error_reason': new_reason}))
 
     def _mark_device_status(self, device_id, exclude_status, new_status):
         context = t_context.get_admin_context()
         with context.session.begin(subtransactions=True):
             try:
                 device_db = (
-                    self._model_query(context, Device).
-                    filter(Device.id == device_id).
-                    filter(~Device.status.in_(exclude_status)).
+                    self._model_query(context, VNF).
+                    filter(VNF.id == device_id).
+                    filter(~VNF.status.in_(exclude_status)).
                     with_lockmode('update').one())
             except orm_exc.NoResultFound:
                 LOG.warning(_('no device found %s'), device_id)
@@ -528,30 +640,6 @@ class VNFMPluginDb(vnfm.VNFMPluginBase, db_base.CommonDbMixin):
         return self._mark_device_status(
             device_id, exclude_status, constants.DEAD)
 
-    # used by failure policy
-    def rename_device_id(self, context, device_id, new_device_id):
-        # ugly hack...
-        context = t_context.get_admin_context()
-        with context.session.begin(subtransactions=True):
-            device_db = self._get_resource(context, Device, device_id)
-            new_device_db = Device(
-                id=new_device_id,
-                tenant_id=device_db.tenant_id,
-                template_id=device_db.template_id,
-                name=device_db.name,
-                description=device_db.description,
-                instance_id=device_db.instance_id,
-                mgmt_url=device_db.mgmt_url,
-                status=device_db.status,
-                vim_id=device_db.vim_id,
-                placement_attr=device_db.placement_attr)
-            context.session.add(new_device_db)
-
-            (self._model_query(context, DeviceAttribute).
-             filter(DeviceAttribute.device_id == device_id).
-             update({'device_id': new_device_id}))
-            context.session.delete(device_db)
-
     def get_vnfs(self, context, filters=None, fields=None):
         return self.get_devices(context, filters, fields)
 
