@@ -37,18 +37,24 @@ class VimInUseException(exceptions.TackerException):
     message = _("VIM %(vim_id)s is still in use by VNF")
 
 
+# Deprecated. Will be removed in Ocata release
 class VimDefaultNameNotDefined(exceptions.TackerException):
     message = _("Default VIM is not set. Either specify a"
                 " valid VIM during the VNF creation or set default VIM"
                 " in tacker.conf")
 
 
+# Deprecated. Will be removed in Ocata release
 class VimDefaultIdException(exceptions.TackerException):
     message = _("Default VIM name %(vim_name)s is invalid or there are "
                 "multiple VIM matches found. Please specify a valid default "
                 "VIM in tacker.conf")
 
 
+class VimDefaultDuplicateException(exceptions.TackerException):
+    message = _("Default VIM already exists %(vim_id)s.")
+
+
 class VimNotFoundException(exceptions.TackerException):
     message = _("Specified VIM id %(vim_id)s is invalid. Please verify and "
                 "pass a valid VIM id")
@@ -66,6 +72,15 @@ class VimDuplicateUrlException(exceptions.TackerException):
     message = _("VIM with specified auth URL already exists. Cannot register "
                 "duplicate VIM")
 
+
+class VimPorjectDomainNameMissingException(exceptions.TackerException):
+    message = _("'project_domain_name' is missing")
+
+
+class VimUserDomainNameMissingException(exceptions.TackerException):
+    message = _("'user_domain_name' is missing")
+
+
 RESOURCE_ATTRIBUTE_MAP = {
 
     'vims': {
@@ -112,7 +127,6 @@ RESOURCE_ATTRIBUTE_MAP = {
             'allow_put': True,
             'validate': {'type:string': None},
             'is_visible': True,
-            'default': '',
         },
         'description': {
             'allow_post': True,
@@ -121,6 +135,12 @@ RESOURCE_ATTRIBUTE_MAP = {
             'is_visible': True,
             'default': '',
         },
+        'status': {
+            'allow_post': False,
+            'allow_put': False,
+            'validate': {'type:string': None},
+            'is_visible': True,
+        },
         'placement_attr': {
             'allow_post': False,
             'allow_put': False,
@@ -134,6 +154,22 @@ RESOURCE_ATTRIBUTE_MAP = {
             'convert_to': attr.convert_to_boolean,
             'required_by_policy': True
         },
+        'is_default': {
+            'allow_post': True,
+            'allow_put': True,
+            'is_visible': True,
+            'default': False
+        },
+        'created_at': {
+            'allow_post': False,
+            'allow_put': False,
+            'is_visible': True,
+        },
+        'updated_at': {
+            'allow_post': False,
+            'allow_put': False,
+            'is_visible': True,
+        },
     }
 }
 
@@ -141,11 +177,11 @@ RESOURCE_ATTRIBUTE_MAP = {
 class Nfvo(extensions.ExtensionDescriptor):
     @classmethod
     def get_name(cls):
-        return 'NFVO'
+        return 'NFV Orchestrator'
 
     @classmethod
     def get_alias(cls):
-        return 'NFV Orchestrator'
+        return 'NFVO'
 
     @classmethod
     def get_description(cls):
@@ -202,12 +238,16 @@ class NFVOPluginBase(service_base.NFVPluginBase):
         pass
 
     @abc.abstractmethod
-    def get_vim(self, context, vim_id, fields=None):
+    def get_vim(self, context, vim_id, fields=None, mask_password=True):
         pass
 
     @abc.abstractmethod
     def get_vims(self, context, filters=None, fields=None):
         pass
 
-    def get_vim_by_name(self, context, vim_name, fields=None):
+    def get_vim_by_name(self, context, vim_name, fields=None,
+                        mask_password=True):
+        raise NotImplementedError()
+
+    def get_default_vim(self, context):
         raise NotImplementedError()
