@@ -15,13 +15,15 @@
 
 import abc
 
+from oslo_log import log as logging
 import six
 
 from tacker.api import extensions
 from tacker.api.v1 import attributes as attr
+from tacker.api.v1 import base
 from tacker.api.v1 import resource_helper
 from tacker.common import exceptions
-from tacker.openstack.common import log as logging
+from tacker import manager
 from tacker.plugins.common import constants
 from tacker.services import service_base
 
@@ -66,7 +68,7 @@ class DeviceCreateFailed(exceptions.TackerException):
 
 
 class DeviceCreateWaitFailed(exceptions.TackerException):
-    message = _('waiting for creation of VNF %(device_id)s failed')
+    message = _('%(reason)s')
 
 
 class DeviceDeleteFailed(exceptions.TackerException):
@@ -74,7 +76,7 @@ class DeviceDeleteFailed(exceptions.TackerException):
 
 
 class DeviceTemplateNotFound(exceptions.NotFound):
-    message = _('VNFD template %(device_tempalte_id)s could not be found')
+    message = _('VNFD template %(device_template_id)s could not be found')
 
 
 class ServiceTypeNotFound(exceptions.NotFound):
@@ -184,7 +186,6 @@ RESOURCE_ATTRIBUTE_MAP = {
             'allow_put': True,
             'validate': {'type:string': None},
             'is_visible': True,
-            'default': '',
         },
         'description': {
             'allow_post': True,
@@ -223,6 +224,16 @@ RESOURCE_ATTRIBUTE_MAP = {
             'is_visible': True,
             'default': None,
         },
+        'created_at': {
+            'allow_post': False,
+            'allow_put': False,
+            'is_visible': True,
+        },
+        'updated_at': {
+            'allow_post': False,
+            'allow_put': False,
+            'is_visible': True,
+        },
     },
 
     'vnfs': {
@@ -258,7 +269,6 @@ RESOURCE_ATTRIBUTE_MAP = {
             'allow_put': True,
             'validate': {'type:string': None},
             'is_visible': True,
-            'default': '',
         },
         'description': {
             'allow_post': True,
@@ -298,18 +308,68 @@ RESOURCE_ATTRIBUTE_MAP = {
             'allow_put': False,
             'is_visible': True,
         },
+        'error_reason': {
+            'allow_post': False,
+            'allow_put': False,
+            'is_visible': True,
+        },
+        'created_at': {
+            'allow_post': False,
+            'allow_put': False,
+            'is_visible': True,
+        },
+        'updated_at': {
+            'allow_post': False,
+            'allow_put': False,
+            'is_visible': True,
+        },
     },
 }
 
 
+SUB_RESOURCE_ATTRIBUTE_MAP = {
+    'actions': {
+        'parent': {
+            'collection_name': 'vnfs',
+            'member_name': 'vnf'
+        },
+        'members': {
+            'scale': {
+                'parameters': {
+                    'policy': {
+                        'allow_post': True,
+                        'allow_put': False,
+                        'is_visible': True,
+                        'validate': {'type:string': None}
+                    },
+                    'type': {
+                        'allow_post': True,
+                        'allow_put': False,
+                        'is_visible': True,
+                        'validate': {'type:string': None}
+                    },
+                    'tenant_id': {
+                        'allow_post': True,
+                        'allow_put': False,
+                        'validate': {'type:string': None},
+                        'required_by_policy': False,
+                        'is_visible': False
+                    },
+                }
+            }
+        }
+    }
+}
+
+
 class Vnfm(extensions.ExtensionDescriptor):
     @classmethod
     def get_name(cls):
-        return 'VNFM'
+        return 'VNF Manager'
 
     @classmethod
     def get_alias(cls):
-        return 'VNF Manager'
+        return 'VNFM'
 
     @classmethod
     def get_description(cls):
@@ -330,9 +390,31 @@ class Vnfm(extensions.ExtensionDescriptor):
             special_mappings, RESOURCE_ATTRIBUTE_MAP)
         plural_mappings['service_types'] = 'service_type'
         attr.PLURALS.update(plural_mappings)
-        return resource_helper.build_resource_info(
+        resources = resource_helper.build_resource_info(
             plural_mappings, RESOURCE_ATTRIBUTE_MAP, constants.VNFM,
             translate_name=True)
+        plugin = manager.TackerManager.get_service_plugins()[
+            constants.VNFM]
+        for collection_name in SUB_RESOURCE_ATTRIBUTE_MAP:
+            parent = SUB_RESOURCE_ATTRIBUTE_MAP[collection_name]['parent']
+
+            for resource_name in SUB_RESOURCE_ATTRIBUTE_MAP[
+                    collection_name]['members']:
+                params = SUB_RESOURCE_ATTRIBUTE_MAP[
+                    collection_name]['members'][resource_name]['parameters']
+
+                controller = base.create_resource(collection_name,
+                                                  resource_name,
+                                                  plugin, params,
+                                                  allow_bulk=True,
+                                                  parent=parent)
+
+            resource = extensions.ResourceExtension(
+                collection_name,
+                controller, parent,
+                attr_map=params)
+            resources.append(resource)
+        return resources
 
     @classmethod
     def get_plugin_interface(cls):
@@ -394,3 +476,8 @@ class VNFMPluginBase(service_base.NFVPluginBase):
     @abc.abstractmethod
     def delete_vnf(self, context, vnf_id):
         pass
+
+    @abc.abstractmethod
+    def create_vnf_scale(
+            self, context, vnf_id, scale):
+        pass
