@@ -18,11 +18,13 @@ import os
 
 from keystoneclient import exceptions
 from oslo_config import cfg
+from oslo_log import log as logging
 
+from tacker._i18n import _LW
+from tacker.agent.linux import utils as linux_utils
 from tacker.common import log
 from tacker.extensions import nfvo
 from tacker.nfvo.drivers.vim import abstract_vim_driver
-from tacker.openstack.common import log as logging
 from tacker.vm import keystone
 
 
@@ -31,7 +33,22 @@ CONF = cfg.CONF
 
 OPTS = [cfg.StrOpt('openstack', default='/etc/tacker/vim/fernet_keys',
                    help='Dir.path to store fernet keys.')]
+
+# same params as we used in ping monitor driver
+OPENSTACK_OPTS = [
+    cfg.StrOpt('count', default='1',
+               help=_('number of ICMP packets to send')),
+    cfg.StrOpt('timeout', default='1',
+               help=_('number of seconds to wait for a response')),
+    cfg.StrOpt('interval', default='1',
+               help=_('number of seconds to wait between packets'))
+]
 cfg.CONF.register_opts(OPTS, 'vim_keys')
+cfg.CONF.register_opts(OPENSTACK_OPTS, 'vim_monitor')
+
+
+def config_opts():
+    return [('vim_keys', OPTS), ('vim_monitor', OPENSTACK_OPTS)]
 
 
 class OpenStack_Driver(abstract_vim_driver.VimAbstractDriver):
@@ -69,20 +86,21 @@ class OpenStack_Driver(abstract_vim_driver.VimAbstractDriver):
         if keystone_version not in auth_url:
             vim_obj['auth_url'] = auth_url + '/' + keystone_version
         if keystone_version == 'v3':
-            auth_cred['project_id'] = vim_project.get('id', None)
-            auth_cred['project_name'] = vim_project.get('name', None)
-            if 'project_domain_id' not in auth_cred:
-                auth_cred[
-                    'project_domain_id'
-                ] = CONF.keystone_authtoken.project_domain_id
-            if 'user_domain_id' not in auth_cred:
-                auth_cred[
-                    'user_domain_id'
-                ] = CONF.keystone_authtoken.user_domain_id
+            auth_cred['project_id'] = vim_project.get('id')
+            auth_cred['project_name'] = vim_project.get('name')
+            if not vim_project.get('project_domain_name'):
+                LOG.error(_("'project_domain_name' is missing."))
+                raise nfvo.VimPorjectDomainNameMissingException()
+            auth_cred['project_domain_name'] = vim_project.get(
+                'project_domain_name')
+            if not auth_cred.get('user_domain_name'):
+                LOG.error(_("'user_domain_name' is missing."))
+                raise nfvo.VimUserDomainNameMissingException()
         else:
-            auth_cred['tenant_id'] = vim_project.get('id', None)
-            auth_cred['tenant_name'] = vim_project.get('name', None)
-            # user_id is not supported in keystone v2
+            auth_cred['tenant_id'] = vim_project.get('id')
+            auth_cred['tenant_name'] = vim_project.get('name')
+            # pop stuff not supported in keystone v2
+            auth_cred.pop('user_domain_name', None)
             auth_cred.pop('user_id', None)
         auth_cred['auth_url'] = vim_obj['auth_url']
         return self._initialize_keystone(keystone_version, auth_cred)
@@ -123,7 +141,7 @@ class OpenStack_Driver(abstract_vim_driver.VimAbstractDriver):
         try:
             regions_list = self._find_regions(ks_client)
         except exceptions.Unauthorized as e:
-            LOG.warn(_("Authorization failed for user"))
+            LOG.warning(_("Authorization failed for user"))
             raise nfvo.VimUnauthorizedException(message=e.message)
         vim_obj['placement_attr'] = {'regions': regions_list}
         return vim_obj
@@ -138,7 +156,7 @@ class OpenStack_Driver(abstract_vim_driver.VimAbstractDriver):
         ks_client = self.authenticate_vim(vim_obj)
         self.discover_placement_attr(vim_obj, ks_client)
         self.encode_vim_auth(vim_obj['id'], vim_obj['auth_cred'])
-        LOG.debug(_('VIM registration complete %s'), vim_obj)
+        LOG.debug(_('VIM registration completed for %s'), vim_obj)
 
     @log.log
     def deregister_vim(self, vim_id):
@@ -160,7 +178,7 @@ class OpenStack_Driver(abstract_vim_driver.VimAbstractDriver):
             os.remove(key_file)
             LOG.debug(_('VIM key deleted successfully for vim %s'), vim_id)
         except OSError:
-            LOG.warn(_('VIM key deletion unsuccessful for vim %s'), vim_id)
+            LOG.warning(_('VIM key deletion unsuccessful for vim %s'), vim_id)
 
     @log.log
     def encode_vim_auth(self, vim_id, auth):
@@ -178,3 +196,20 @@ class OpenStack_Driver(abstract_vim_driver.VimAbstractDriver):
                 LOG.debug(_('VIM auth successfully stored for vim %s'), vim_id)
         except IOError:
             raise nfvo.VimKeyNotFoundException(vim_id=vim_id)
+
+    @log.log
+    def vim_status(self, auth_url):
+        """Checks the VIM health status"""
+        vim_ip = auth_url.split("//")[-1].split(":")[0].split("/")[0]
+        ping_cmd = ['ping',
+                    '-c', cfg.CONF.vim_monitor.count,
+                    '-W', cfg.CONF.vim_monitor.timeout,
+                    '-i', cfg.CONF.vim_monitor.interval,
+                    vim_ip]
+
+        try:
+            linux_utils.execute(ping_cmd, check_exit_code=True)
+            return True
+        except RuntimeError:
+            LOG.warning(_LW("Cannot ping ip address: %s"), vim_ip)
+            return False
