@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 OpenStack Foundation.
 # All Rights Reserved.
 #
@@ -20,20 +18,26 @@ CORE = "CORE"
 DUMMY = "DUMMY"
 VNFM = "VNFM"
 NFVO = "NFVO"
+COMMONSERVICES = "COMMONSERVICES"
 
 COMMON_PREFIXES = {
     CORE: "",
     DUMMY: "/dummy_svc",
     VNFM: "",
-    NFVO: ""
+    NFVO: "",
+    COMMONSERVICES: ""
 }
 
 # Service operation status constants
 ACTIVE = "ACTIVE"
 DOWN = "DOWN"
+
 PENDING_CREATE = "PENDING_CREATE"
 PENDING_UPDATE = "PENDING_UPDATE"
 PENDING_DELETE = "PENDING_DELETE"
+PENDING_SCALE_IN = "PENDING_SCALE_IN"
+PENDING_SCALE_OUT = "PENDING_SCALE_OUT"
+
 INACTIVE = "INACTIVE"
 DEAD = "DEAD"
 ERROR = "ERROR"
@@ -43,3 +47,21 @@ ACTIVE_PENDING_STATUSES = (
     PENDING_CREATE,
     PENDING_UPDATE
 )
+
+POLICY_SCALING = 'tosca.policy.tacker.Scaling'
+POLICY_SCALING_ACTIONS = (ACTION_SCALE_OUT,
+                          ACTION_SCALE_IN) = ('out', 'in')
+POLICY_ACTIONS = {POLICY_SCALING: POLICY_SCALING_ACTIONS}
+
+RES_TYPE_VNFD = "vnfd"
+RES_TYPE_VNF = "vnf"
+RES_TYPE_VIM = "vim"
+
+RES_EVT_CREATE = "CREATE"
+RES_EVT_DELETE = "DELETE"
+RES_EVT_UPDATE = "UPDATE"
+RES_EVT_VNFD_NA_STATE = "Not Applicable"
+
+RES_EVT_CREATED_FLD = "created_at"
+RES_EVT_DELETED_FLD = "deleted_at"
+RES_EVT_UPDATED_FLD = "updated_at"
