@@ -14,10 +14,14 @@
 
 import time
 
+from novaclient import client as nova_client
 from oslo_config import cfg
 from tempest_lib.tests import base
+import yaml
 
+from tacker.common.exceptions import TackerException
 from tacker.tests import constants
+from tacker.tests.utils import read_file
 from tacker import version
 
 from tackerclient.v1_0 import client as tacker_client
@@ -30,22 +34,6 @@ class BaseTackerTest(base.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        core_opts = [
-            cfg.StrOpt('username', default='tacker',
-                       help=('Username to use for tacker API requests')),
-            cfg.StrOpt('password', default = 'devstack',
-                       help=('Password to use for tacker API requests')),
-            cfg.StrOpt('project_name', default = 'service',
-                       help=('Project name to use for tacker API requests')),
-            cfg.StrOpt('auth_uri', default='http://127.0.0.1:5000',
-                       help=('The keystone auth URI')),
-        ]
-
-        keystone_authtoken = cfg.OptGroup(name='keystone_authtoken',
-                                          title='keystone options')
-        # Register the configuration options
-        cfg.CONF.register_opts(core_opts, group=keystone_authtoken)
-
         kwargs = {}
 
         cfg.CONF(args=['--config-file', '/etc/tacker/tacker.conf'],
@@ -55,15 +43,27 @@ class BaseTackerTest(base.TestCase):
 
         cls.client = cls.tackerclient()
 
+    @classmethod
+    def get_credentials(cls):
+        vim_params = yaml.load(read_file('local-vim.yaml'))
+        vim_params['auth_url'] += '/v2.0'
+        return vim_params
+
     @classmethod
     def tackerclient(cls):
-        username = cfg.CONF.keystone_authtoken.username
-        password = cfg.CONF.keystone_authtoken.password
-        tenant_name = cfg.CONF.keystone_authtoken.project_name
-        auth_uri = cfg.CONF.keystone_authtoken.auth_uri + '/v2.0'
-        return tacker_client.Client(username=username, password=password,
-                                    tenant_name=tenant_name,
-                                    auth_url=auth_uri)
+        vim_params = cls.get_credentials()
+        return tacker_client.Client(username=vim_params['username'],
+                                    password=vim_params['password'],
+                                    tenant_name=vim_params['project_name'],
+                                    auth_url=vim_params['auth_url'])
+
+    @classmethod
+    def novaclient(cls):
+        vim_params = cls.get_credentials()
+        return nova_client.Client('2', vim_params['username'],
+                                  vim_params['password'],
+                                  vim_params['project_name'],
+                                  vim_params['auth_url'])
 
     @classmethod
     def wait_until_vnf_status(cls, vnf_id, target_status, timeout,
@@ -85,6 +85,20 @@ class BaseTackerTest(base.TestCase):
         return cls.wait_until_vnf_status(vnf_id, 'ACTIVE', timeout,
                                          sleep_interval)
 
+    @classmethod
+    def wait_until_vnf_delete(cls, vnf_id, timeout):
+        start_time = int(time.time())
+        while True:
+            try:
+                vnf_result = cls.client.show_vnf(vnf_id)
+                time.sleep(1)
+            except Exception:
+                return
+            status = vnf_result['vnf']['status']
+            if (status != 'PENDING_DELETE') or ((
+                    int(time.time()) - start_time) > timeout):
+                raise TackerException(_("Failed with status: %s"), status)
+
     @classmethod
     def wait_until_vnf_dead(cls, vnf_id, timeout, sleep_interval):
         return cls.wait_until_vnf_status(vnf_id, 'DEAD', timeout,
@@ -103,7 +117,7 @@ class BaseTackerTest(base.TestCase):
             vnf_id,
             constants.VNF_CIRROS_CREATE_TIMEOUT,
             constants.ACTIVE_SLEEP_TIME)
-        self.assertEqual(vnf_current_status, 'ACTIVE')
+        self.assertEqual('ACTIVE', vnf_current_status)
         self.validate_vnf_instance(vnfd_instance, vnf_instance)
         self.assertIsNotNone(self.client.show_vnf(vnf_id)['vnf']['mgmt_url'])
 
@@ -111,12 +125,12 @@ class BaseTackerTest(base.TestCase):
             vnf_id,
             constants.VNF_CIRROS_DEAD_TIMEOUT,
             constants.DEAD_SLEEP_TIME)
-        self.assertEqual(vnf_current_status, 'DEAD')
+        self.assertEqual('DEAD', vnf_current_status)
         vnf_current_status = self.wait_until_vnf_active(
             vnf_id,
             constants.VNF_CIRROS_CREATE_TIMEOUT,
             constants.ACTIVE_SLEEP_TIME)
-        self.assertEqual(vnf_current_status, 'ACTIVE')
+        self.assertEqual('ACTIVE', vnf_current_status)
         self.validate_vnf_instance(vnfd_instance, vnf_instance)
 
     def get_vim(self, vim_list, vim_name):
