@@ -12,6 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from tacker.tests import constants
 from tacker.tests.functional import base
 from tacker.tests.utils import read_file
 
@@ -22,7 +23,8 @@ class VnfTestPingMonitor(base.BaseTackerTest):
         data = dict()
         data['tosca'] = read_file(vnfd_file)
         toscal = data['tosca']
-        tosca_arg = {'vnfd': {'attributes': {'vnfd': toscal}}}
+        tosca_arg = {'vnfd': {'name': vnf_name,
+                              'attributes': {'vnfd': toscal}}}
 
         # Create vnfd with tosca template
         vnfd_instance = self.client.create_vnfd(body=tosca_arg)
@@ -45,11 +47,9 @@ class VnfTestPingMonitor(base.BaseTackerTest):
                            vnf_id)
 
         # Delete vnfd_instance
-        try:
-            self.client.delete_vnfd(vnfd_id)
-        except Exception:
-            assert False, ("Failed to delete vnfd %s after the monitor test" %
-                           vnfd_id)
+        self.addCleanup(self.client.delete_vnfd, vnfd_id)
+        self.addCleanup(self.wait_until_vnf_delete, vnf_id,
+            constants.VNF_CIRROS_DELETE_TIMEOUT)
 
     def test_create_delete_vnf_monitoring(self):
         self._test_vnf_with_monitoring(
@@ -70,3 +70,18 @@ class VnfTestPingMonitor(base.BaseTackerTest):
         self._test_vnf_with_monitoring(
             'sample-vnfd-single-vdu-monitoring-new-template.yaml',
             'ping monitor vnf new template')
+
+    def test_create_delete_vnf_monitoring_tosca_template(self):
+        self._test_vnf_with_monitoring(
+            'sample-tosca-vnfd-monitor.yaml',
+            'ping monitor vnf with tosca template')
+
+    def test_create_delete_vnf_multi_vdu_monitoring_tosca_template(self):
+        self._test_vnf_with_monitoring(
+            'sample-tosca-vnfd-multi-vdu-monitoring.yaml',
+            'ping monitor multi vdu vnf with tosca template')
+
+    def test_create_delete_vnf_http_monitoring_tosca_template(self):
+        self._test_vnf_with_monitoring(
+            'sample-tosca-vnfd-http-monitor.yaml',
+            'http monitor vnf with tosca template')
