@@ -12,19 +12,21 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import yaml
+
 from tacker.tests import constants
 from tacker.tests.functional import base
 from tacker.tests.utils import read_file
 
-import yaml
-
 
 class VnfmTestParam(base.BaseTackerTest):
     def _test_vnfd_create(self, vnfd_file):
         yaml_input = dict()
         yaml_input['tosca'] = read_file(vnfd_file)
+        vnfd_name = 'sample_cirros_vnf'
         toscal = yaml_input['tosca']
-        req_dict = {'vnfd': {'attributes': {'vnfd': toscal}}}
+        req_dict = {'vnfd': {'name': vnfd_name,
+                    'attributes': {'vnfd': toscal}}}
 
         # Create vnfd
         vnfd_instance = self.client.create_vnfd(body=req_dict)
@@ -87,14 +89,28 @@ class VnfmTestParam(base.BaseTackerTest):
         except Exception:
             assert True, "Vnf Delete success" + str(vfn_d) + str(Exception)
 
-    def test_vnfd_param(self):
-        vnfd_instance = self._test_vnfd_create('sample_cirros_vnf_param.yaml')
-        self._test_vnfd_delete(vnfd_instance)
-
     def test_vnf_param(self):
         vnfd_instance = self._test_vnfd_create('sample_cirros_vnf_param.yaml')
         vnf_instance = self._test_vnf_create(vnfd_instance,
                                              'test_vnf_with_parameters',
                                              'sample_cirros_vnf_values.yaml')
         self._test_vnf_delete(vnf_instance)
+        vnf_id = vnf_instance['vnf']['id']
+        self.addCleanup(self.client.delete_vnfd, vnfd_instance['vnfd']['id'])
+        self.addCleanup(self.wait_until_vnf_delete, vnf_id,
+            constants.VNF_CIRROS_DELETE_TIMEOUT)
+
+    def test_vnfd_param_tosca_template(self):
+        vnfd_instance = self._test_vnfd_create('sample-tosca-vnfd-param.yaml')
         self._test_vnfd_delete(vnfd_instance)
+
+    def test_vnf_param_tosca_template(self):
+        vnfd_instance = self._test_vnfd_create('sample-tosca-vnfd-param.yaml')
+        vnf_instance = self._test_vnf_create(vnfd_instance,
+                                    'test_vnf_with_parameters_tosca_template',
+                                             'sample-tosca-vnf-values.yaml')
+        self._test_vnf_delete(vnf_instance)
+        vnf_id = vnf_instance['vnf']['id']
+        self.addCleanup(self.client.delete_vnfd, vnfd_instance['vnfd']['id'])
+        self.addCleanup(self.wait_until_vnf_delete, vnf_id,
+            constants.VNF_CIRROS_DELETE_TIMEOUT)
