@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright (c) 2012 OpenStack Foundation.
 # All Rights Reserved.
 #
@@ -19,6 +17,8 @@ import os
 
 import mock
 from oslo_config import cfg
+from oslo_policy import policy as common_policy
+from oslo_utils import uuidutils
 import six
 import six.moves.urllib.parse as urlparse
 import webob
@@ -33,8 +33,6 @@ from tacker.api.v1 import router
 from tacker.common import exceptions as n_exc
 from tacker import context
 from tacker import manager
-from tacker.openstack.common import policy as common_policy
-from tacker.openstack.common import uuidutils
 from tacker import policy
 from tacker.tests import base
 from tacker.tests import fake_notifier
@@ -68,23 +66,23 @@ class ResourceIndexTestCase(base.BaseTestCase):
         res = index.get('')
 
         self.assertIn('resources', res.json)
-        self.assertEqual(len(res.json['resources']), 1)
+        self.assertEqual(1, len(res.json['resources']))
 
         resource = res.json['resources'][0]
         self.assertIn('collection', resource)
-        self.assertEqual(resource['collection'], 'bar')
+        self.assertEqual('bar', resource['collection'])
 
         self.assertIn('name', resource)
-        self.assertEqual(resource['name'], 'foo')
+        self.assertEqual('foo', resource['name'])
 
         self.assertIn('links', resource)
-        self.assertEqual(len(resource['links']), 1)
+        self.assertEqual(1, len(resource['links']))
 
         link = resource['links'][0]
         self.assertIn('href', link)
-        self.assertEqual(link['href'], 'http://localhost/bar')
+        self.assertEqual('http://localhost/bar', link['href'])
         self.assertIn('rel', link)
-        self.assertEqual(link['rel'], 'self')
+        self.assertEqual('self', link['rel'])
 
 
 class APIv2TestBase(base.BaseTestCase):
@@ -316,7 +314,7 @@ class APIv2TestCase(APIv2TestBase):
 
         res = self.api.get(_get_path('networks'), {'limit': -1},
                            expect_errors=True)
-        self.assertEqual(res.status_int, exc.HTTPBadRequest.code)
+        self.assertEqual(exc.HTTPBadRequest.code, res.status_int)
 
     def test_limit_with_non_integer(self):
         instance = self.plugin.return_value
@@ -324,7 +322,7 @@ class APIv2TestCase(APIv2TestBase):
 
         res = self.api.get(_get_path('networks'),
                            {'limit': 'abc'}, expect_errors=True)
-        self.assertEqual(res.status_int, exc.HTTPBadRequest.code)
+        self.assertEqual(exc.HTTPBadRequest.code, res.status_int)
 
     def test_limit_with_infinite_pagination_max_limit(self):
         instance = self.plugin.return_value
@@ -424,7 +422,7 @@ class APIv2TestCase(APIv2TestBase):
 
         res = self.api.get(_get_path('networks'), {'sort_key': ['name']},
                            expect_errors=True)
-        self.assertEqual(res.status_int, exc.HTTPBadRequest.code)
+        self.assertEqual(exc.HTTPBadRequest.code, res.status_int)
 
     def test_sort_with_invalid_attribute(self):
         instance = self.plugin.return_value
@@ -434,7 +432,7 @@ class APIv2TestCase(APIv2TestBase):
                            {'sort_key': 'abc',
                             'sort_dir': 'asc'},
                            expect_errors=True)
-        self.assertEqual(res.status_int, exc.HTTPBadRequest.code)
+        self.assertEqual(exc.HTTPBadRequest.code, res.status_int)
 
     def test_sort_with_invalid_dirs(self):
         instance = self.plugin.return_value
@@ -536,15 +534,15 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
         self.assertIn('networks', res)
         if not req_tenant_id or req_tenant_id == real_tenant_id:
             # expect full list returned
-            self.assertEqual(len(res['networks']), 1)
+            self.assertEqual(1, len(res['networks']))
             output_dict = res['networks'][0]
             input_dict['shared'] = False
             self.assertEqual(len(input_dict), len(output_dict))
-            for k, v in input_dict.iteritems():
+            for k, v in six.iteritems(input_dict):
                 self.assertEqual(v, output_dict[k])
         else:
             # expect no results
-            self.assertEqual(len(res['networks']), 0)
+            self.assertEqual(0, len(res['networks']))
 
     def test_list_noauth(self):
         self._test_list(None, _uuid())
@@ -584,7 +582,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
         res = self.api.get(_get_path('networks'),
                            params=params).json
 
-        self.assertEqual(len(res['networks']), 2)
+        self.assertEqual(2, len(res['networks']))
         self.assertEqual(sorted([id1, id2]),
                          sorted([res['networks'][0]['id'],
                                 res['networks'][1]['id']]))
@@ -597,19 +595,19 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                 next_links.append(r)
             if r['rel'] == 'previous':
                 previous_links.append(r)
-        self.assertEqual(len(next_links), 1)
-        self.assertEqual(len(previous_links), 1)
+        self.assertEqual(1, len(next_links))
+        self.assertEqual(1, len(previous_links))
 
         url = urlparse.urlparse(next_links[0]['href'])
-        self.assertEqual(url.path, _get_path('networks'))
+        self.assertEqual(_get_path('networks'), url.path)
         params['marker'] = [id2]
-        self.assertEqual(urlparse.parse_qs(url.query), params)
+        self.assertEqual(params, urlparse.parse_qs(url.query))
 
         url = urlparse.urlparse(previous_links[0]['href'])
-        self.assertEqual(url.path, _get_path('networks'))
+        self.assertEqual(_get_path('networks'), url.path)
         params['marker'] = [id1]
         params['page_reverse'] = ['True']
-        self.assertEqual(urlparse.parse_qs(url.query), params)
+        self.assertEqual(params, urlparse.parse_qs(url.query))
 
     def test_list_pagination_with_last_page(self):
         id = str(_uuid())
@@ -628,7 +626,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
         res = self.api.get(_get_path('networks'),
                            params=params).json
 
-        self.assertEqual(len(res['networks']), 1)
+        self.assertEqual(1, len(res['networks']))
         self.assertEqual(id, res['networks'][0]['id'])
 
         self.assertIn('networks_links', res)
@@ -637,14 +635,14 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
             self.assertNotEqual(r['rel'], 'next')
             if r['rel'] == 'previous':
                 previous_links.append(r)
-        self.assertEqual(len(previous_links), 1)
+        self.assertEqual(1, len(previous_links))
 
         url = urlparse.urlparse(previous_links[0]['href'])
-        self.assertEqual(url.path, _get_path('networks'))
+        self.assertEqual(_get_path('networks'), url.path)
         expect_params = params.copy()
         expect_params['marker'] = [id]
         expect_params['page_reverse'] = ['True']
-        self.assertEqual(urlparse.parse_qs(url.query), expect_params)
+        self.assertEqual(expect_params, urlparse.parse_qs(url.query))
 
     def test_list_pagination_with_empty_page(self):
         return_value = []
@@ -655,7 +653,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
         res = self.api.get(_get_path('networks'),
                            params=params).json
 
-        self.assertEqual(res['networks'], [])
+        self.assertEqual([], res['networks'])
 
         previous_links = []
         if 'networks_links' in res:
@@ -663,14 +661,14 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                 self.assertNotEqual(r['rel'], 'next')
                 if r['rel'] == 'previous':
                     previous_links.append(r)
-        self.assertEqual(len(previous_links), 1)
+        self.assertEqual(1, len(previous_links))
 
         url = urlparse.urlparse(previous_links[0]['href'])
-        self.assertEqual(url.path, _get_path('networks'))
+        self.assertEqual(_get_path('networks'), url.path)
         expect_params = params.copy()
         del expect_params['marker']
         expect_params['page_reverse'] = ['True']
-        self.assertEqual(urlparse.parse_qs(url.query), expect_params)
+        self.assertEqual(expect_params, urlparse.parse_qs(url.query))
 
     def test_list_pagination_reverse_with_last_page(self):
         id = str(_uuid())
@@ -690,7 +688,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
         res = self.api.get(_get_path('networks'),
                            params=params).json
 
-        self.assertEqual(len(res['networks']), 1)
+        self.assertEqual(1, len(res['networks']))
         self.assertEqual(id, res['networks'][0]['id'])
 
         self.assertIn('networks_links', res)
@@ -699,15 +697,15 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
             self.assertNotEqual(r['rel'], 'previous')
             if r['rel'] == 'next':
                 next_links.append(r)
-        self.assertEqual(len(next_links), 1)
+        self.assertEqual(1, len(next_links))
 
         url = urlparse.urlparse(next_links[0]['href'])
-        self.assertEqual(url.path, _get_path('networks'))
+        self.assertEqual(_get_path('networks'), url.path)
         expected_params = params.copy()
         del expected_params['page_reverse']
         expected_params['marker'] = [id]
-        self.assertEqual(urlparse.parse_qs(url.query),
-                         expected_params)
+        self.assertEqual(expected_params,
+                         urlparse.parse_qs(url.query))
 
     def test_list_pagination_reverse_with_empty_page(self):
         return_value = []
@@ -718,7 +716,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                   'page_reverse': ['True']}
         res = self.api.get(_get_path('networks'),
                            params=params).json
-        self.assertEqual(res['networks'], [])
+        self.assertEqual([], res['networks'])
 
         next_links = []
         if 'networks_links' in res:
@@ -726,14 +724,14 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                 self.assertNotEqual(r['rel'], 'previous')
                 if r['rel'] == 'next':
                     next_links.append(r)
-        self.assertEqual(len(next_links), 1)
+        self.assertEqual(1, len(next_links))
 
         url = urlparse.urlparse(next_links[0]['href'])
-        self.assertEqual(url.path, _get_path('networks'))
+        self.assertEqual(_get_path('networks'), url.path)
         expect_params = params.copy()
         del expect_params['marker']
         del expect_params['page_reverse']
-        self.assertEqual(urlparse.parse_qs(url.query), expect_params)
+        self.assertEqual(expect_params, urlparse.parse_qs(url.query))
 
     def test_create(self):
         net_id = _uuid()
@@ -750,12 +748,12 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
         res = self.api.post(_get_path('networks', fmt=self.fmt),
                             self.serialize(data),
                             content_type='application/' + self.fmt)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('network', res)
         net = res['network']
-        self.assertEqual(net['id'], net_id)
-        self.assertEqual(net['status'], "ACTIVE")
+        self.assertEqual(net_id, net['id'])
+        self.assertEqual("ACTIVE", net['status'])
 
     def test_create_use_defaults(self):
         net_id = _uuid()
@@ -776,13 +774,13 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                             content_type='application/' + self.fmt)
         instance.create_network.assert_called_with(mock.ANY,
                                                    network=full_input)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('network', res)
         net = res['network']
-        self.assertEqual(net['id'], net_id)
-        self.assertEqual(net['admin_state_up'], True)
-        self.assertEqual(net['status'], "ACTIVE")
+        self.assertEqual(net_id, net['id'])
+        self.assertEqual(True, net['admin_state_up'])
+        self.assertEqual("ACTIVE", net['status'])
 
     def test_create_no_keystone_env(self):
         data = {'name': 'net1'}
@@ -790,7 +788,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                             self.serialize(data),
                             content_type='application/' + self.fmt,
                             expect_errors=True)
-        self.assertEqual(res.status_int, exc.HTTPBadRequest.code)
+        self.assertEqual(exc.HTTPBadRequest.code, res.status_int)
 
     def test_create_with_keystone_env(self):
         tenant_id = _uuid()
@@ -816,7 +814,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
 
         instance.create_network.assert_called_with(mock.ANY,
                                                    network=full_input)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
 
     def test_create_bad_keystone_tenant(self):
         tenant_id = _uuid()
@@ -827,7 +825,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                             content_type='application/' + self.fmt,
                             expect_errors=True,
                             extra_environ=env)
-        self.assertEqual(res.status_int, exc.HTTPBadRequest.code)
+        self.assertEqual(exc.HTTPBadRequest.code, res.status_int)
 
     def test_create_no_body(self):
         data = {'whoa': None}
@@ -835,7 +833,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                             self.serialize(data),
                             content_type='application/' + self.fmt,
                             expect_errors=True)
-        self.assertEqual(res.status_int, exc.HTTPBadRequest.code)
+        self.assertEqual(exc.HTTPBadRequest.code, res.status_int)
 
     def test_create_no_resource(self):
         data = {}
@@ -843,7 +841,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                             self.serialize(data),
                             content_type='application/' + self.fmt,
                             expect_errors=True)
-        self.assertEqual(res.status_int, exc.HTTPBadRequest.code)
+        self.assertEqual(exc.HTTPBadRequest.code, res.status_int)
 
     def test_create_missing_attr(self):
         data = {'port': {'what': 'who', 'tenant_id': _uuid()}}
@@ -851,7 +849,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                             self.serialize(data),
                             content_type='application/' + self.fmt,
                             expect_errors=True)
-        self.assertEqual(res.status_int, 400)
+        self.assertEqual(400, res.status_int)
 
     def test_create_readonly_attr(self):
         data = {'network': {'name': 'net1', 'tenant_id': _uuid(),
@@ -860,7 +858,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                             self.serialize(data),
                             content_type='application/' + self.fmt,
                             expect_errors=True)
-        self.assertEqual(res.status_int, 400)
+        self.assertEqual(400, res.status_int)
 
     def test_create_bulk(self):
         data = {'networks': [{'name': 'net1',
@@ -881,7 +879,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
         res = self.api.post(_get_path('networks', fmt=self.fmt),
                             self.serialize(data),
                             content_type='application/' + self.fmt)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
 
     def test_create_bulk_no_networks(self):
         data = {'networks': []}
@@ -889,7 +887,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                             self.serialize(data),
                             content_type='application/' + self.fmt,
                             expect_errors=True)
-        self.assertEqual(res.status_int, exc.HTTPBadRequest.code)
+        self.assertEqual(exc.HTTPBadRequest.code, res.status_int)
 
     def test_create_bulk_missing_attr(self):
         data = {'ports': [{'what': 'who', 'tenant_id': _uuid()}]}
@@ -897,7 +895,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                             self.serialize(data),
                             content_type='application/' + self.fmt,
                             expect_errors=True)
-        self.assertEqual(res.status_int, 400)
+        self.assertEqual(400, res.status_int)
 
     def test_create_bulk_partial_body(self):
         data = {'ports': [{'device_id': 'device_1',
@@ -907,7 +905,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                             self.serialize(data),
                             content_type='application/' + self.fmt,
                             expect_errors=True)
-        self.assertEqual(res.status_int, 400)
+        self.assertEqual(400, res.status_int)
 
     def test_create_attr_not_specified(self):
         net_id = _uuid()
@@ -938,12 +936,12 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                             self.serialize(initial_input),
                             content_type='application/' + self.fmt)
         instance.create_port.assert_called_with(mock.ANY, port=full_input)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('port', res)
         port = res['port']
-        self.assertEqual(port['network_id'], net_id)
-        self.assertEqual(port['mac_address'], 'ca:fe:de:ad:be:ef')
+        self.assertEqual(net_id, port['network_id'])
+        self.assertEqual('ca:fe:de:ad:be:ef', port['mac_address'])
 
     def test_create_return_extra_attr(self):
         net_id = _uuid()
@@ -960,12 +958,12 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
         res = self.api.post(_get_path('networks', fmt=self.fmt),
                             self.serialize(data),
                             content_type='application/' + self.fmt)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('network', res)
         net = res['network']
-        self.assertEqual(net['id'], net_id)
-        self.assertEqual(net['status'], "ACTIVE")
+        self.assertEqual(net_id, net['id'])
+        self.assertEqual("ACTIVE", net['status'])
         self.assertNotIn('v2attrs:something', net)
 
     def test_fields(self):
@@ -994,7 +992,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                                         fmt=self.fmt),
                               extra_environ=env,
                               expect_errors=expect_errors)
-        self.assertEqual(res.status_int, expected_code)
+        self.assertEqual(expected_code, res.status_int)
 
     def test_delete_noauth(self):
         self._test_delete(None, _uuid(), exc.HTTPNoContent.code)
@@ -1027,7 +1025,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                                      fmt=self.fmt),
                            extra_environ=env,
                            expect_errors=expect_errors)
-        self.assertEqual(res.status_int, expected_code)
+        self.assertEqual(expected_code, res.status_int)
         return res
 
     def test_get_noauth(self):
@@ -1084,7 +1082,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
         #  in update procedure.
         self.assertEqual(1, instance.get_network.call_count)
         self.assertIn('id', instance.get_network.call_args[1]['fields'])
-        self.assertEqual(res.status_int, expected_code)
+        self.assertEqual(expected_code, res.status_int)
 
     def test_update_noauth(self):
         self._test_update(None, _uuid(), 200)
@@ -1104,7 +1102,7 @@ class JSONV2TestCase(APIv2TestBase, testlib_api.WebTestCase):
                            self.serialize(data),
                            content_type='application/' + self.fmt,
                            expect_errors=True)
-        self.assertEqual(res.status_int, 400)
+        self.assertEqual(400, res.status_int)
 
     def test_invalid_attribute_field(self):
         data = {'network': {'invalid_key1': "foo1", 'invalid_key2': "foo2"}}
@@ -1124,7 +1122,8 @@ class SubresourceTest(base.BaseTestCase):
 
         # Save the global RESOURCE_ATTRIBUTE_MAP
         self.saved_attr_map = {}
-        for resource, attrs in attributes.RESOURCE_ATTRIBUTE_MAP.iteritems():
+        for resource, attrs in six.iteritems(
+                attributes.RESOURCE_ATTRIBUTE_MAP):
             self.saved_attr_map[resource] = attrs.copy()
 
         self.config_parse()
@@ -1270,13 +1269,13 @@ class NotificationTest(APIv2TestBase):
 
         expected_events = ('.'.join([resource, opname, "start"]),
                            '.'.join([resource, opname, "end"]))
-        self.assertEqual(len(fake_notifier.NOTIFICATIONS),
-                         len(expected_events))
+        self.assertEqual(len(expected_events),
+                         len(fake_notifier.NOTIFICATIONS))
         for msg, event in zip(fake_notifier.NOTIFICATIONS, expected_events):
             self.assertEqual('INFO', msg['priority'])
             self.assertEqual(event, msg['event_type'])
 
-        self.assertEqual(res.status_int, expected_code)
+        self.assertEqual(expected_code, res.status_int)
 
     def test_network_create_notifer(self):
         self._resource_op_notifier('create', 'network')
@@ -1298,7 +1297,8 @@ class ExtensionTestCase(base.BaseTestCase):
 
         # Save the global RESOURCE_ATTRIBUTE_MAP
         self.saved_attr_map = {}
-        for resource, attrs in attributes.RESOURCE_ATTRIBUTE_MAP.iteritems():
+        for resource, attrs in six.iteritems(
+                attributes.RESOURCE_ATTRIBUTE_MAP):
             self.saved_attr_map[resource] = attrs.copy()
 
         # Create the default configurations
@@ -1345,12 +1345,12 @@ class ExtensionTestCase(base.BaseTestCase):
 
         instance.create_network.assert_called_with(mock.ANY,
                                                    network=data)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         self.assertIn('network', res.json)
         net = res.json['network']
-        self.assertEqual(net['id'], net_id)
-        self.assertEqual(net['status'], "ACTIVE")
-        self.assertEqual(net['v2attrs:something'], "123")
+        self.assertEqual(net_id, net['id'])
+        self.assertEqual("ACTIVE", net['status'])
+        self.assertEqual("123", net['v2attrs:something'])
         self.assertNotIn('v2attrs:something_else', net)
 
 
@@ -1379,7 +1379,7 @@ class ListArgsTestCase(base.BaseTestCase):
         request = webob.Request.blank(path)
         expect_val = ['2', '4']
         actual_val = api_common.list_args(request, 'fields')
-        self.assertEqual(sorted(actual_val), expect_val)
+        self.assertEqual(expect_val, sorted(actual_val))
 
     def test_list_args_with_empty(self):
         path = '/?foo=4&bar=3&baz=2&qux=1'
@@ -1404,7 +1404,7 @@ class FiltersTestCase(base.BaseTestCase):
         request = webob.Request.blank(path)
         expect_val = {'foo': ['4'], 'bar': ['3'], 'baz': ['2'], 'qux': ['1']}
         actual_val = api_common.get_filters(request, {})
-        self.assertEqual(actual_val, expect_val)
+        self.assertEqual(expect_val, actual_val)
 
     def test_attr_info_without_conversion(self):
         path = '/?foo=4&bar=3&baz=2&qux=1'
@@ -1412,7 +1412,7 @@ class FiltersTestCase(base.BaseTestCase):
         attr_info = {'foo': {'key': 'val'}}
         expect_val = {'foo': ['4'], 'bar': ['3'], 'baz': ['2'], 'qux': ['1']}
         actual_val = api_common.get_filters(request, attr_info)
-        self.assertEqual(actual_val, expect_val)
+        self.assertEqual(expect_val, actual_val)
 
     def test_attr_info_with_convert_list_to(self):
         path = '/?foo=key=4&bar=3&foo=key=2&qux=1'
@@ -1424,7 +1424,7 @@ class FiltersTestCase(base.BaseTestCase):
         }
         expect_val = {'foo': {'key': ['2', '4']}, 'bar': ['3'], 'qux': ['1']}
         actual_val = api_common.get_filters(request, attr_info)
-        self.assertEqual(actual_val, expect_val)
+        self.assertEqual(expect_val, actual_val)
 
     def test_attr_info_with_convert_to(self):
         path = '/?foo=4&bar=3&baz=2&qux=1'
@@ -1432,7 +1432,7 @@ class FiltersTestCase(base.BaseTestCase):
         attr_info = {'foo': {'convert_to': attributes.convert_to_int}}
         expect_val = {'foo': [4], 'bar': ['3'], 'baz': ['2'], 'qux': ['1']}
         actual_val = api_common.get_filters(request, attr_info)
-        self.assertEqual(actual_val, expect_val)
+        self.assertEqual(expect_val, actual_val)
 
 
 class CreateResourceTestCase(base.BaseTestCase):
