@@ -14,6 +14,7 @@
 #    under the License.
 
 import codecs
+import json
 import mock
 import os
 import yaml
@@ -96,23 +97,28 @@ class TestDeviceHeat(base.TestCase):
                 '-d5a1-4fd4-9447-bb9243c8460b',
                 'template': self.hot_ipparam_template}
 
-    def _get_expected_device_wait_obj(self):
-        return {'status': 'PENDING_CREATE', 'instance_id': None, 'name':
-            u'test_openwrt', 'tenant_id':
-        u'ad7ebc56538745a08ef7c5e97f8bd437', 'template_id':
-        u'eb094833-995e-49f0-a047-dfb56aaf7c4e', 'device_template': {
-            'service_types': [{'service_type': u'vnfd', 'id':
-            u'4a4c2d44-8a52-4895-9a75-9d1c76c3e738'}], 'description':
-            u'OpenWRT with services', 'tenant_id':
-            u'ad7ebc56538745a08ef7c5e97f8bd437', 'mgmt_driver': u'openwrt',
-            'infra_driver': u'heat',
-            'attributes': {u'vnfd': self.vnfd_openwrt},
-            'id': u'fb048660-dc1b-4f0f-bd89-b023666650ec', 'name':
-            u'openwrt_services'}, 'mgmt_url': '{"vdu1": "192.168.120.31"}',
-                'service_context': [], 'attributes': {
-            u'param_values': u''}, 'id':
-            'eb84260e-5ff7-4332-b032-50a14d6c1123', 'description':
-            u'OpenWRT with services'}
+    def _get_expected_device_wait_obj(self, param_values=''):
+        return {'status': 'PENDING_CREATE',
+                'instance_id': None,
+                'name': u'test_openwrt',
+                'tenant_id': u'ad7ebc56538745a08ef7c5e97f8bd437',
+                'template_id': u'eb094833-995e-49f0-a047-dfb56aaf7c4e',
+                'device_template': {
+                    'service_types': [{
+                        'service_type': u'vnfd',
+                        'id': u'4a4c2d44-8a52-4895-9a75-9d1c76c3e738'}],
+                    'description': u'OpenWRT with services',
+                    'tenant_id': u'ad7ebc56538745a08ef7c5e97f8bd437',
+                    'mgmt_driver': u'openwrt',
+                    'infra_driver': u'heat',
+                    'attributes': {u'vnfd': self.vnfd_openwrt},
+                    'id': u'fb048660-dc1b-4f0f-bd89-b023666650ec',
+                    'name': u'openwrt_services'},
+                'mgmt_url': '{"vdu1": "192.168.120.31"}',
+                'service_context': [],
+                'attributes': {u'param_values': param_values},
+                'id': 'eb84260e-5ff7-4332-b032-50a14d6c1123',
+                'description': u'OpenWRT with services'}
 
     def _get_expected_device_update_obj(self):
         return {'status': 'PENDING_CREATE', 'instance_id': None, 'name':
@@ -176,7 +182,7 @@ class TestDeviceHeat(base.TestCase):
                                      device_dict=device_obj,
                                      device_id=device_id,
                                      auth_attr=utils.get_vim_auth_obj())
-        self.assertEqual(device_obj, expected_result)
+        self.assertEqual(expected_result, device_obj)
 
     def test_delete(self):
         device_id = '4a4c2d44-8a52-4895-9a75-9d1c76c3e738'
@@ -194,14 +200,14 @@ class TestDeviceHeat(base.TestCase):
                                 device_id=device_id, device_dict=device_obj,
                                 device=device_config_obj,
                                 auth_attr=utils.get_vim_auth_obj())
-        self.assertEqual(device_obj, expected_device_update)
+        self.assertEqual(expected_device_update, device_obj)
 
     def test_create_device_template_pre_tosca(self):
         tosca_tpl = _get_template('test_tosca_openwrt.yaml')
         dtemplate = self._get_device_template(tosca_tpl)
         exp_tmpl = self._get_expected_device_template(tosca_tpl)
         self.heat_driver.create_device_template_pre(None, None, dtemplate)
-        self.assertEqual(dtemplate, exp_tmpl)
+        self.assertEqual(exp_tmpl, dtemplate)
 
     def _get_expected_fields_tosca(self, template):
         return {'stack_name':
@@ -209,27 +215,43 @@ class TestDeviceHeat(base.TestCase):
                 '-5ff7-4332-b032-50a14d6c1123',
                 'template': _get_template(template)}
 
-    def _get_expected_tosca_device(self, tosca_tpl_name, hot_tpl_name):
+    def _get_expected_tosca_device(self,
+                                   tosca_tpl_name,
+                                   hot_tpl_name,
+                                   param_values='',
+                                   is_monitor=True):
         tosca_tpl = _get_template(tosca_tpl_name)
         exp_tmpl = self._get_expected_device_template(tosca_tpl)
         tosca_hw_dict = yaml.safe_load(_get_template(hot_tpl_name))
-        return {'device_template': exp_tmpl['device_template'],
-                'description': u'OpenWRT with services',
-                'attributes': {'heat_template': tosca_hw_dict,
-                               'monitoring_policy': '{"vdus": {"VDU1":'
-                               ' {"ping": {"name": "ping",'
-                               ' "actions": {"failure": "respawn"},'
-                               ' "parameters": {"count": 3, "interval": 10'
-                               '}, "monitoring_params": {"count": 3, '
-                               '"interval": 10}}}}}',
-                               'param_values': ''},
-                'id': 'eb84260e-5ff7-4332-b032-50a14d6c1123',
-                'instance_id': None, 'mgmt_url': None, 'name': u'test_openwrt',
-                'service_context': [], 'status': 'PENDING_CREATE',
-                'template_id': u'eb094833-995e-49f0-a047-dfb56aaf7c4e',
-                'tenant_id': u'ad7ebc56538745a08ef7c5e97f8bd437'}
+        dvc = {
+            'device_template': exp_tmpl['device_template'],
+            'description': u'OpenWRT with services',
+            'attributes': {
+                'heat_template': tosca_hw_dict,
+                'param_values': param_values
+            },
+            'id': 'eb84260e-5ff7-4332-b032-50a14d6c1123',
+            'instance_id': None,
+            'mgmt_url': None,
+            'name': u'test_openwrt',
+            'service_context': [],
+            'status': 'PENDING_CREATE',
+            'template_id': u'eb094833-995e-49f0-a047-dfb56aaf7c4e',
+            'tenant_id': u'ad7ebc56538745a08ef7c5e97f8bd437'
+        }
+        # Add montitoring attributes for those yaml, which are having it
+        if is_monitor:
+            dvc['attributes'].update(
+                {'monitoring_policy': '{"vdus": {"VDU1": {"ping": {"name": '
+                                      '"ping", "actions": {"failure": '
+                                      '"respawn"}, "parameters": {"count": 3, '
+                                      '"interval": 10}, "monitoring_params": '
+                                      '{"count": 3, "interval": 10}}}}}'})
+
+        return dvc
+
+    def _get_dummy_tosca_device(self, template, input_params=''):
 
-    def _get_dummy_tosca_device(self, template):
         tosca_template = _get_template(template)
         device = utils.get_dummy_device_obj()
         dtemplate = self._get_expected_device_template(tosca_template)
@@ -237,15 +259,23 @@ class TestDeviceHeat(base.TestCase):
             '4a4c2d44-8a52-4895-9a75-9d1c76c3e738'}]
         dtemplate['tenant_id'] = 'ad7ebc56538745a08ef7c5e97f8bd437'
         device['device_template'] = dtemplate['device_template']
+        device['attributes'] = {}
+        device['attributes']['param_values'] = input_params
         return device
 
-    def _test_assert_equal_for_tosca_templates(self, tosca_tpl_name,
-                                               hot_tpl_name):
-        device = self._get_dummy_tosca_device(tosca_tpl_name)
+    def _test_assert_equal_for_tosca_templates(self,
+                                               tosca_tpl_name,
+                                               hot_tpl_name,
+                                               input_params='',
+                                               files=None,
+                                               is_monitor=True):
+        device = self._get_dummy_tosca_device(tosca_tpl_name, input_params)
         expected_result = '4a4c2d44-8a52-4895-9a75-9d1c76c3e738'
         expected_fields = self._get_expected_fields_tosca(hot_tpl_name)
         expected_device = self._get_expected_tosca_device(tosca_tpl_name,
-                                                          hot_tpl_name)
+                                                          hot_tpl_name,
+                                                          input_params,
+                                                          is_monitor)
         result = self.heat_driver.create(plugin=None, context=self.context,
                                          device=device,
                                          auth_attr=utils.get_vim_auth_obj())
@@ -253,12 +283,34 @@ class TestDeviceHeat(base.TestCase):
         actual_fields["template"] = yaml.safe_load(actual_fields["template"])
         expected_fields["template"] = \
             yaml.safe_load(expected_fields["template"])
-        self.assertEqual(actual_fields, expected_fields)
+
+        if files:
+            for k, v in actual_fields["files"].items():
+                actual_fields["files"][k] = yaml.safe_load(v)
+
+            expected_fields["files"] = {}
+            for k, v in files.items():
+                expected_fields["files"][k] = yaml.safe_load(_get_template(v))
+
+        self.assertEqual(expected_fields, actual_fields)
         device["attributes"]["heat_template"] = yaml.safe_load(
             device["attributes"]["heat_template"])
         self.heat_client.create.assert_called_once_with(expected_fields)
         self.assertEqual(expected_result, result)
-        self.assertEqual(device, expected_device)
+
+        if files:
+            expected_fields["files"] = {}
+            for k, v in files.items():
+                expected_device["attributes"][k] = yaml.safe_load(
+                    _get_template(v))
+                device["attributes"][k] = yaml.safe_load(
+                    device["attributes"][k])
+            expected_device["attributes"]['scaling_group_names'] = {
+                'SP1': 'G1'}
+            device["attributes"]['scaling_group_names'] = json.loads(
+                device["attributes"]['scaling_group_names']
+            )
+        self.assertEqual(expected_device, device)
 
     def test_create_tosca(self):
         # self.skipTest("Not ready yet")
@@ -322,3 +374,37 @@ class TestDeviceHeat(base.TestCase):
     def test_create_tosca_with_new_image(self):
         self._test_assert_equal_for_tosca_templates('test_tosca_image.yaml',
             'hot_tosca_image.yaml')
+
+    def test_create_tosca_sriov(self):
+        self._test_assert_equal_for_tosca_templates(
+            'tosca_sriov.yaml',
+            'hot_tosca_sriov.yaml'
+        )
+
+    def test_create_tosca_vnic_normal(self):
+        self._test_assert_equal_for_tosca_templates(
+            'tosca_vnic_port.yaml',
+            'hot_tosca_vnic_normal.yaml'
+        )
+
+    def test_create_tosca_mgmt_sriov_port(self):
+        self._test_assert_equal_for_tosca_templates(
+            'tosca_mgmt_sriov.yaml',
+            'hot_tosca_mgmt_sriov.yaml'
+        )
+
+    def test_tosca_params(self):
+        input_params = 'image: cirros\nflavor: m1.large'
+        self._test_assert_equal_for_tosca_templates(
+            'tosca_generic_vnfd_params.yaml',
+            'hot_tosca_generic_vnfd_params.yaml',
+            input_params
+        )
+
+    def test_create_tosca_scale(self):
+        self._test_assert_equal_for_tosca_templates(
+            'tosca_scale.yaml',
+            'hot_scale_main.yaml',
+            files={'scaling.yaml': 'hot_scale_custom.yaml'},
+            is_monitor=False
+        )
