@@ -77,7 +77,7 @@ class TestVNFMonitor(testtools.TestCase):
         }
         output_dict = VNFMonitor.to_hosting_vnf(test_device_dict,
                                                 action_cb)
-        self.assertDictEqual(expected_output, output_dict)
+        self.assertEqual(expected_output, output_dict)
 
     @mock.patch('tacker.vm.monitor.VNFMonitor.__run__')
     def test_add_hosting_vnf(self, mock_monitor_run):
@@ -85,8 +85,8 @@ class TestVNFMonitor(testtools.TestCase):
         test_boot_wait = 30
         test_vnfmonitor = VNFMonitor(test_boot_wait)
         test_vnfmonitor.add_hosting_vnf(test_device_dict)
-        test_device_id = test_vnfmonitor._hosting_vnfs.keys()[0]
-        self.assertEqual(test_device_id, MOCK_DEVICE_ID)
+        test_device_id = list(test_vnfmonitor._hosting_vnfs.keys())[0]
+        self.assertEqual(MOCK_DEVICE_ID, test_device_id)
 
     @mock.patch('tacker.vm.monitor.VNFMonitor.__run__')
     def test_run_monitor(self, mock_monitor_run):
