@@ -18,9 +18,11 @@ import uuid
 import mock
 
 from tacker import context
+from tacker.db.common_services import common_services_db
 from tacker.db.nfvo import nfvo_db
 from tacker.db.vm import vm_db
 from tacker.extensions import vnfm
+from tacker.plugins.common import constants
 from tacker.tests.unit.db import base as db_base
 from tacker.tests.unit.db import utils
 from tacker.vm import plugin
@@ -56,6 +58,10 @@ class TestVNFMPlugin(db_base.SqlTestCase):
         self._mock_green_pool()
         self._insert_dummy_vim()
         self.vnfm_plugin = plugin.VNFMPlugin()
+        mock.patch('tacker.db.common_services.common_services_db.'
+                   'CommonServicesPluginDb.create_event'
+                   ).start()
+        self._cos_db_plugin = common_services_db.CommonServicesPluginDb()
 
     def _mock_device_manager(self):
         self._device_manager = mock.Mock(wraps=FakeDriverManager())
@@ -97,7 +103,7 @@ class TestVNFMPlugin(db_base.SqlTestCase):
 
     def _insert_dummy_device_template(self):
         session = self.context.session
-        device_template = vm_db.DeviceTemplate(
+        device_template = vm_db.VNFD(
             id='eb094833-995e-49f0-a047-dfb56aaf7c4e',
             tenant_id='ad7ebc56538745a08ef7c5e97f8bd437',
             name='fake_template',
@@ -110,13 +116,13 @@ class TestVNFMPlugin(db_base.SqlTestCase):
 
     def _insert_dummy_device(self):
         session = self.context.session
-        device_db = vm_db.Device(
+        device_db = vm_db.VNF(
             id='6261579e-d6f3-49ad-8bc3-a9cb974778ff',
             tenant_id='ad7ebc56538745a08ef7c5e97f8bd437',
             name='fake_device',
             description='fake_device_description',
             instance_id='da85ea1a-4ec4-4201-bbb2-8d9249eca7ec',
-            template_id='eb094833-995e-49f0-a047-dfb56aaf7c4e',
+            vnfd_id='eb094833-995e-49f0-a047-dfb56aaf7c4e',
             vim_id='6261579e-d6f3-49ad-8bc3-a9cb974778ff',
             placement_attr={'region': 'RegionOne'},
             status='ACTIVE')
@@ -132,6 +138,7 @@ class TestVNFMPlugin(db_base.SqlTestCase):
             name='fake_vim',
             description='fake_vim_description',
             type='openstack',
+            status='Active',
             placement_attr={'regions': ['RegionOne']})
         vim_auth_db = nfvo_db.VimAuth(
             vim_id='6261579e-d6f3-49ad-8bc3-a9cb974778ff',
@@ -151,12 +158,18 @@ class TestVNFMPlugin(db_base.SqlTestCase):
         self.assertIn('id', result)
         self.assertIn('service_types', result)
         self.assertIn('attributes', result)
+        self.assertIn('created_at', result)
+        self.assertIn('updated_at', result)
         self._device_manager.invoke.assert_called_once_with(
             mock.ANY,
             mock.ANY,
             plugin=mock.ANY,
             context=mock.ANY,
             device_template=mock.ANY)
+        self._cos_db_plugin.create_event.assert_called_once_with(
+            self.context, evt_type=constants.RES_EVT_CREATE, res_id=mock.ANY,
+            res_state=constants.RES_EVT_VNFD_NA_STATE,
+            res_type=constants.RES_TYPE_VNFD, tstamp=mock.ANY)
 
     def test_create_vnfd_no_service_types(self):
         vnfd_obj = utils.get_dummy_vnfd_obj()
@@ -182,12 +195,18 @@ class TestVNFMPlugin(db_base.SqlTestCase):
         self.assertIn('status', result)
         self.assertIn('attributes', result)
         self.assertIn('mgmt_url', result)
+        self.assertIn('created_at', result)
+        self.assertIn('updated_at', result)
         self._device_manager.invoke.assert_called_with(mock.ANY, mock.ANY,
                                                        plugin=mock.ANY,
                                                        context=mock.ANY,
                                                        device=mock.ANY,
                                                        auth_attr=mock.ANY)
         self._pool.spawn_n.assert_called_once_with(mock.ANY)
+        self._cos_db_plugin.create_event.assert_called_with(
+            self.context, evt_type=constants.RES_EVT_CREATE, res_id=mock.ANY,
+            res_state=mock.ANY, res_type=constants.RES_TYPE_VNF,
+            tstamp=mock.ANY, details=mock.ANY)
 
     def test_delete_vnf(self):
         self._insert_dummy_device_template()
@@ -203,6 +222,10 @@ class TestVNFMPlugin(db_base.SqlTestCase):
         self._vnf_monitor.delete_hosting_vnf.assert_called_with(mock.ANY)
         self._pool.spawn_n.assert_called_once_with(mock.ANY, mock.ANY,
                                                    mock.ANY, mock.ANY)
+        self._cos_db_plugin.create_event.assert_called_with(
+            self.context, evt_type=constants.RES_EVT_DELETE, res_id=mock.ANY,
+            res_state=mock.ANY, res_type=constants.RES_TYPE_VNF,
+            tstamp=mock.ANY, details=mock.ANY)
 
     def test_update_vnf(self):
         self._insert_dummy_device_template()
@@ -216,5 +239,10 @@ class TestVNFMPlugin(db_base.SqlTestCase):
         self.assertIn('status', result)
         self.assertIn('attributes', result)
         self.assertIn('mgmt_url', result)
+        self.assertIn('updated_at', result)
         self._pool.spawn_n.assert_called_once_with(mock.ANY, mock.ANY,
                                                    mock.ANY, mock.ANY)
+        self._cos_db_plugin.create_event.assert_called_with(
+            self.context, evt_type=constants.RES_EVT_UPDATE, res_id=mock.ANY,
+            res_state=mock.ANY, res_type=constants.RES_TYPE_VNF,
+            tstamp=mock.ANY)
