@@ -1,8 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-#
 # Copyright 2013, 2014 Intel Corporation.
-# Copyright 2013, 2014 Isaku Yamahata <isaku.yamahata at intel com>
-#                                     <isaku.yamahata at gmail com>
 # All Rights Reserved.
 #
 #
@@ -20,14 +16,17 @@
 
 import time
 
+
 from keystoneclient import auth as ks_auth
 from keystoneclient.auth.identity import v2 as v2_auth
 from keystoneclient import session as ks_session
 from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_log import versionutils
+from six import iteritems
 
 from tacker.api.v1 import attributes
-from tacker.i18n import _LE, _LW
-from tacker.openstack.common import log as logging
+from tacker._i18n import _LE, _LW
 from tacker.vm.infra_drivers import abstract_driver
 
 LOG = logging.getLogger(__name__)
@@ -73,6 +72,11 @@ class DeviceNova(abstract_driver.DeviceAbstractDriver):
 
     """Nova driver of hosting device."""
 
+    @versionutils.deprecated(
+        versionutils.deprecated.NEWTON,
+        what='infra_driver nova',
+        in_favor_of='infra_driver heat',
+        remove_in=+1)
     def __init__(self):
         super(DeviceNova, self).__init__()
         # avoid circular import
@@ -143,8 +147,8 @@ class DeviceNova(abstract_driver.DeviceAbstractDriver):
             port_data['fixed_ips'] = [{'subnet_id': subnet_id}]
 
         # See api.v2.base.prepare_request_body()
-        for attr, attr_vals in attributes.RESOURCE_ATTRIBUTE_MAP[
-                attributes.PORTS].iteritems():
+        for attr, attr_vals in iteritems(attributes.RESOURCE_ATTRIBUTE_MAP[
+                attributes.PORTS]):
             if not attr_vals.get('allow_post', False):
                 continue
             if attr in port_data:
