@@ -1,8 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-#
 # Copyright 2013, 2014 Intel Corporation.
-# Copyright 2013, 2014 Isaku Yamahata <isaku.yamahata at intel com>
-#                                     <isaku.yamahata at gmail com>
 # All Rights Reserved.
 #
 #
@@ -20,10 +16,10 @@
 
 import abc
 
+from oslo_serialization import jsonutils
 import six
 
 from tacker.api import extensions
-from tacker.openstack.common import jsonutils
 from tacker.vm import constants
 
 
