@@ -1,8 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-#
 # Copyright 2013, 2014 Intel Corporation.
-# Copyright 2013, 2014 Isaku Yamahata <isaku.yamahata at intel com>
-#                                     <isaku.yamahata at gmail com>
 # All Rights Reserved.
 #
 #
@@ -18,7 +14,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from tacker.openstack.common import log as logging
+from oslo_log import log as logging
+
 from tacker.vm.mgmt_drivers import abstract_driver
 
 
