@@ -13,12 +13,12 @@
 #
 
 from oslo_config import cfg
+from oslo_log import log as logging
 import six.moves.urllib.error as urlerr
 import six.moves.urllib.request as urlreq
 
+from tacker._i18n import _LW
 from tacker.common import log
-from tacker.i18n import _LW
-from tacker.openstack.common import log as logging
 from tacker.vm.monitor_drivers import abstract_driver
 
 
@@ -34,6 +34,10 @@ OPTS = [
 cfg.CONF.register_opts(OPTS, 'monitor_http_ping')
 
 
+def config_opts():
+    return [('monitor_http_ping', OPTS)]
+
+
 class VNFMonitorHTTPPing(abstract_driver.VNFMonitorAbstractDriver):
     def get_type(self):
         return 'http_ping'
