@@ -13,11 +13,11 @@
 #
 
 from oslo_config import cfg
+from oslo_log import log as logging
 
+from tacker._i18n import _LW
 from tacker.agent.linux import utils as linux_utils
 from tacker.common import log
-from tacker.i18n import _LW
-from tacker.openstack.common import log as logging
 from tacker.vm.monitor_drivers import abstract_driver
 
 
@@ -33,6 +33,10 @@ OPTS = [
 cfg.CONF.register_opts(OPTS, 'monitor_ping')
 
 
+def config_opts():
+    return [('monitor_ping', OPTS)]
+
+
 class VNFMonitorPing(abstract_driver.VNFMonitorAbstractDriver):
     def get_type(self):
         return 'ping'
