@@ -1,8 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-#
 # Copyright 2013, 2014 Intel Corporation.
-# Copyright 2013, 2014 Isaku Yamahata <isaku.yamahata at intel com>
-#                                     <isaku.yamahata at gmail com>
 # All Rights Reserved.
 #
 #
@@ -20,17 +16,21 @@
 
 import copy
 import inspect
+import six
+import yaml
 
 import eventlet
 from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_log import versionutils
+from oslo_utils import excutils
 
+from tacker._i18n import _LE
 from tacker.api.v1 import attributes
 from tacker.common import driver_manager
+from tacker.common import exceptions
 from tacker.db.vm import vm_db
 from tacker.extensions import vnfm
-from tacker.i18n import _LE
-from tacker.openstack.common import excutils
-from tacker.openstack.common import log as logging
 from tacker.plugins.common import constants
 from tacker.vm.mgmt_drivers import constants as mgmt_constants
 from tacker.vm import monitor
@@ -40,6 +40,11 @@ LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
+def config_opts():
+    return [('tacker', VNFMMgmtMixin.OPTS),
+            ('tacker', VNFMPlugin.OPTS)]
+
+
 class VNFMMgmtMixin(object):
     OPTS = [
         cfg.ListOpt(
@@ -131,6 +136,11 @@ class VNFMPlugin(vm_db.VNFMPluginDb, VNFMMgmtMixin):
 
     def create_device_template(self, context, device_template):
         template = device_template['device_template']
+        if "tosca_definitions_version" not in template['attributes']['vnfd']:
+            versionutils.report_deprecated_feature(LOG, 'VNFD legacy templates'
+                ' are deprecated since Mitaka release and will be removed in'
+                ' Ocata release. Please use NFV TOSCA templates.')
+
         LOG.debug(_('template %s'), template)
 
         infra_driver = template.get('infra_driver')
@@ -204,10 +214,12 @@ class VNFMPlugin(vm_db.VNFMPluginDb, VNFMMgmtMixin):
                 driver_name, 'create_wait', plugin=self, context=context,
                 device_dict=device_dict, device_id=instance_id,
                 auth_attr=auth_attr)
-        except vnfm.DeviceCreateWaitFailed:
+        except vnfm.DeviceCreateWaitFailed as e:
             LOG.error(_LE("VNF Create failed for vnf_id %s"), device_id)
             create_failed = True
             device_dict['status'] = constants.ERROR
+            self.set_device_error_status_reason(context, device_id,
+                                                six.text_type(e))
 
         if instance_id is None or create_failed:
             mgmt_url = None
@@ -232,9 +244,11 @@ class VNFMPlugin(vm_db.VNFMPluginDb, VNFMMgmtMixin):
         new_status = constants.ACTIVE
         try:
             self.mgmt_call(context, device_dict, kwargs)
-        except Exception:
-            LOG.exception(_('create_device_wait'))
+        except exceptions.MgmtDriverException:
+            LOG.error(_('VNF configuration failed'))
             new_status = constants.ERROR
+            self.set_device_error_status_reason(context, device_id,
+            'Unable to configure VDU')
         device_dict['status'] = new_status
         self._create_device_status(context, device_id, new_status)
 
@@ -248,7 +262,8 @@ class VNFMPlugin(vm_db.VNFMPluginDb, VNFMMgmtMixin):
         return vim_res['vim_auth']
 
     def _create_device(self, context, device, vim_auth):
-        device_dict = self._create_device_pre(context, device)
+        device_dict = self._create_device_pre(
+            context, device) if not device.get('id') else device
         device_id = device_dict['id']
         driver_name = self._infra_driver_name(device_dict)
         LOG.debug(_('device_dict %s'), device_dict)
@@ -283,9 +298,8 @@ class VNFMPlugin(vm_db.VNFMPluginDb, VNFMMgmtMixin):
     # not for wsgi, but for service to create hosting device
     # the device is NOT added to monitor.
     def create_device_sync(self, context, device):
-        device_info = device['device']
-        vim_auth = self.get_vim(context, device_info)
-        device_dict = self._create_device(context, device_info, vim_auth)
+        vim_auth = self.get_vim(context, device)
+        device_dict = self._create_device(context, device, vim_auth)
         self._create_device_wait(context, device_dict, vim_auth)
         return device_dict
 
@@ -298,7 +312,7 @@ class VNFMPlugin(vm_db.VNFMPluginDb, VNFMMgmtMixin):
         }
         new_status = constants.ACTIVE
         placement_attr = device_dict['placement_attr']
-        region_name = placement_attr.get('region_name', None)
+        region_name = placement_attr.get('region_name')
 
         try:
             self._device_manager.invoke(
@@ -306,9 +320,11 @@ class VNFMPlugin(vm_db.VNFMPluginDb, VNFMMgmtMixin):
                 context=context, device_id=instance_id, auth_attr=vim_auth,
                 region_name=region_name)
             self.mgmt_call(context, device_dict, kwargs)
-        except Exception:
-            LOG.exception(_('_update_device_wait'))
+        except exceptions.MgmtDriverException as e:
+            LOG.error(_('VNF configuration failed'))
             new_status = constants.ERROR
+            self.set_device_error_status_reason(context, device_dict['id'],
+                                                six.text_type(e))
         device_dict['status'] = new_status
         self.mgmt_update_post(context, device_dict)
 
@@ -327,9 +343,12 @@ class VNFMPlugin(vm_db.VNFMPluginDb, VNFMMgmtMixin):
                 driver_name, 'update', plugin=self, context=context,
                 device_id=instance_id, device_dict=device_dict,
                 device=device, auth_attr=vim_auth)
-        except Exception:
+        except Exception as e:
             with excutils.save_and_reraise_exception():
                 device_dict['status'] = constants.ERROR
+                self.set_device_error_status_reason(context,
+                                                    device_dict['id'],
+                                                    six.text_type(e))
                 self.mgmt_update_post(context, device_dict)
                 self._update_device_post(context, device_id, constants.ERROR)
 
@@ -340,17 +359,24 @@ class VNFMPlugin(vm_db.VNFMPluginDb, VNFMMgmtMixin):
         driver_name = self._infra_driver_name(device_dict)
         instance_id = self._instance_id(device_dict)
         e = None
-        placement_attr = device_dict['placement_attr']
-        region_name = placement_attr.get('region_name', None)
-        try:
-            self._device_manager.invoke(
-                driver_name, 'delete_wait', plugin=self,
-                context=context, device_id=instance_id, auth_attr=auth_attr,
-                region_name=region_name)
-        except Exception as e_:
-            e = e_
-            device_dict['status'] = constants.ERROR
-            LOG.exception(_('_delete_device_wait'))
+        if instance_id:
+            placement_attr = device_dict['placement_attr']
+            region_name = placement_attr.get('region_name')
+            try:
+                self._device_manager.invoke(
+                    driver_name,
+                    'delete_wait',
+                    plugin=self,
+                    context=context,
+                    device_id=instance_id,
+                    auth_attr=auth_attr,
+                    region_name=region_name)
+            except Exception as e_:
+                e = e_
+                device_dict['status'] = constants.ERROR
+                device_dict['error_reason'] = six.text_type(e)
+                LOG.exception(_('_delete_device_wait'))
+
         self.mgmt_delete_post(context, device_dict)
         device_id = device_dict['id']
         self._delete_device_post(context, device_id, e)
@@ -362,7 +388,7 @@ class VNFMPlugin(vm_db.VNFMPluginDb, VNFMMgmtMixin):
         driver_name = self._infra_driver_name(device_dict)
         instance_id = self._instance_id(device_dict)
         placement_attr = device_dict['placement_attr']
-        region_name = placement_attr.get('region_name', None)
+        region_name = placement_attr.get('region_name')
         kwargs = {
             mgmt_constants.KEY_ACTION: mgmt_constants.ACTION_DELETE_DEVICE,
             mgmt_constants.KEY_KWARGS: {'device': device_dict},
@@ -370,30 +396,154 @@ class VNFMPlugin(vm_db.VNFMPluginDb, VNFMMgmtMixin):
         try:
             self.mgmt_delete_pre(context, device_dict)
             self.mgmt_call(context, device_dict, kwargs)
-            self._device_manager.invoke(driver_name, 'delete', plugin=self,
-                                        context=context,
-                                        device_id=instance_id,
-                                        auth_attr=vim_auth,
-                                        region_name=region_name)
+            if instance_id:
+                self._device_manager.invoke(driver_name,
+                                            'delete',
+                                            plugin=self,
+                                            context=context,
+                                            device_id=instance_id,
+                                            auth_attr=vim_auth,
+                                            region_name=region_name)
         except Exception as e:
             # TODO(yamahata): when the devaice is already deleted. mask
             # the error, and delete row in db
             # Other case mark error
             with excutils.save_and_reraise_exception():
                 device_dict['status'] = constants.ERROR
+                device_dict['error_reason'] = six.text_type(e)
                 self.mgmt_delete_post(context, device_dict)
                 self._delete_device_post(context, device_id, e)
 
-        self._delete_device_post(context, device_id, None)
         self.spawn_n(self._delete_device_wait, context, device_dict, vim_auth)
 
+    def _handle_vnf_scaling(self, context, policy):
+        # validate
+        def _validate_scaling_policy():
+            type = policy['type']
+
+            if type not in constants.POLICY_ACTIONS.keys():
+                raise exceptions.VnfPolicyTypeInvalid(
+                    type=type,
+                    valid_types=constants.POLICY_ACTIONS.keys(),
+                    policy=policy['id']
+                )
+            action = policy['action']
+
+            if action not in constants.POLICY_ACTIONS[type]:
+                raise exceptions.VnfPolicyActionInvalid(
+                    action=action,
+                    valid_actions=constants.POLICY_ACTIONS[type],
+                    policy=policy['id']
+                )
+
+            LOG.debug(_("Policy %s is validated successfully") % policy)
+
+        def _get_status():
+            if policy['action'] == constants.ACTION_SCALE_IN:
+                status = constants.PENDING_SCALE_IN
+            else:
+                status = constants.PENDING_SCALE_OUT
+
+            return status
+
+        # pre
+        def _handle_vnf_scaling_pre():
+            status = _get_status()
+            result = self._update_vnf_scaling_status(context,
+                                                     policy,
+                                                     [constants.ACTIVE],
+                                                     status)
+            LOG.debug(_("Policy %(policy)s vnf is at %(status)s"),
+                      {'policy': policy,
+                       'status': status})
+            return result
+
+        # post
+        def _handle_vnf_scaling_post(new_status, mgmt_url=None):
+            status = _get_status()
+            result = self._update_vnf_scaling_status(context,
+                                                     policy,
+                                                     [status],
+                                                     new_status,
+                                                     mgmt_url)
+            LOG.debug(_("Policy %(policy)s vnf is at %(status)s"),
+                      {'policy': policy,
+                       'status': new_status})
+            return result
+
+        # action
+        def _vnf_policy_action():
+            try:
+                self._device_manager.invoke(
+                    infra_driver,
+                    'scale',
+                    plugin=self,
+                    context=context,
+                    auth_attr=vim_auth,
+                    policy=policy,
+                    region_name=region_name
+                )
+                LOG.debug(_("Policy %s action is started successfully") %
+                          policy)
+            except Exception as e:
+                LOG.error(_("Policy %s action is failed to start") %
+                          policy)
+                with excutils.save_and_reraise_exception():
+                    vnf['status'] = constants.ERROR
+                    self.set_device_error_status_reason(
+                        context,
+                        policy['vnf_id'],
+                        six.text_type(e))
+                    _handle_vnf_scaling_post(constants.ERROR)
+
+        # wait
+        def _vnf_policy_action_wait():
+            try:
+                LOG.debug(_("Policy %s action is in progress") %
+                          policy)
+                mgmt_url = self._device_manager.invoke(
+                    infra_driver,
+                    'scale_wait',
+                    plugin=self,
+                    context=context,
+                    auth_attr=vim_auth,
+                    policy=policy,
+                    region_name=region_name
+                )
+                LOG.debug(_("Policy %s action is completed successfully") %
+                          policy)
+                _handle_vnf_scaling_post(constants.ACTIVE, mgmt_url)
+                # TODO(kanagaraj-manickam): Add support for config and mgmt
+            except Exception as e:
+                LOG.error(_("Policy %s action is failed to complete") %
+                          policy)
+                with excutils.save_and_reraise_exception():
+                    self.set_device_error_status_reason(
+                        context,
+                        policy['vnf_id'],
+                        six.text_type(e))
+                    _handle_vnf_scaling_post(constants.ERROR)
+
+        _validate_scaling_policy()
+
+        vnf = _handle_vnf_scaling_pre()
+        policy['instance_id'] = vnf['instance_id']
+
+        infra_driver = self._infra_driver_name(vnf)
+        vim_auth = self.get_vim(context, vnf)
+        region_name = vnf.get('placement_attr', {}).get('region_name', None)
+        _vnf_policy_action()
+        self.spawn_n(_vnf_policy_action_wait)
+
+        return policy
+
     def create_vnf(self, context, vnf):
         vnf['device'] = vnf.pop('vnf')
         vnf_attributes = vnf['device']
         vnf_attributes['template_id'] = vnf_attributes.pop('vnfd_id')
         vnf_dict = self.create_device(context, vnf)
         vnf_response = copy.deepcopy(vnf_dict)
-        vnf_response['vnfd_id'] = vnf_response.pop('template_id')
+        vnf_response['vnfd_id'] = vnf_response.pop('vnfd_id')
         return vnf_response
 
     def update_vnf(
@@ -408,3 +558,59 @@ class VNFMPlugin(vm_db.VNFMPluginDb, VNFMMgmtMixin):
         vnfd['device_template'] = vnfd.pop('vnfd')
         new_dict = self.create_device_template(context, vnfd)
         return new_dict
+
+    def _make_policy_dict(self, vnf, name, policy):
+        p = {}
+        p['type'] = policy['type']
+        p['properties'] = policy['properties']
+        p['vnf'] = vnf
+        p['name'] = name
+        p['id'] = p['name']
+        return p
+
+    def get_vnf_policies(
+            self, context, vnf_id, filters=None, fields=None):
+        vnf = self.get_device(context, vnf_id)
+        vnfd_tmpl = yaml.load(vnf['device_template']['attributes']['vnfd'])
+        policy_list = []
+
+        if vnfd_tmpl.get('tosca_definitions_version'):
+            polices = vnfd_tmpl['topology_template'].get('policies', [])
+            for policy_dict in polices:
+                for name, policy in policy_dict.items():
+                    def _add(policy):
+                        p = self._make_policy_dict(vnf, name, policy)
+                        p['name'] = name
+                        policy_list.append(p)
+
+                    # Check for filters
+                    if filters.get('name'):
+                        if name == filters.get('name'):
+                            _add(policy)
+                            break
+                        else:
+                            continue
+
+                    _add(policy)
+
+        return policy_list
+
+    def get_vnf_policy(
+            self, context, policy_id, vnf_id, fields=None):
+        policies = self.get_vnf_policies(context,
+                                         vnf_id,
+                                         filters={'name': policy_id})
+        if policies:
+            return policies[0]
+
+        raise exceptions.VnfPolicyNotFound(policy=policy_id,
+                                           vnf_id=vnf_id)
+
+    def create_vnf_scale(self, context, vnf_id, scale):
+        policy_ = self.get_vnf_policy(context,
+                                      scale['scale']['policy'],
+                                      vnf_id)
+        policy_.update({'action': scale['scale']['type']})
+        self._handle_vnf_scaling(context, policy_)
+
+        return scale['scale']
