@@ -16,13 +16,14 @@ import re
 import sys
 import yaml
 
+from oslo_log import log as logging
+from six import iteritems
+from toscaparser.properties import Property
+from toscaparser.utils import yamlparser
+
 from tacker.common import log
 from tacker.common import utils
 from tacker.extensions import vnfm
-from tacker.openstack.common import log as logging
-
-from toscaparser.properties import Property
-from toscaparser.utils import yamlparser
 
 
 FAILURE = 'tosca.policies.tacker.Failure'
@@ -65,7 +66,12 @@ delpropmap = {TACKERVDU: ('mgmt_driver', 'config', 'service_type',
               TACKERCP: ('management',)}
 
 convert_prop = {TACKERCP: {'anti_spoofing_protection':
-                           'port_security_enabled'}}
+                           'port_security_enabled',
+                           'type':
+                           'binding:vnic_type'}}
+
+convert_prop_values = {TACKERCP: {'sriov': 'direct',
+                                  'vnic': 'normal'}}
 
 deletenodes = (MONITORING, FAILURE, PLACEMENT)
 
@@ -90,12 +96,12 @@ def updateimports(template):
 
         template['imports'].append(nfvfile)
 
-    LOG.debug(_("%s") % path)
+    LOG.debug(_("%s"), path)
 
 
 @log.log
 def get_vdu_monitoring(template):
-    monitoring_dict = {'vdus': {}}
+    monitoring_dict = {}
     for nt in template.nodetemplates:
         if nt.type_definition.is_derived_from(TACKERVDU):
             mon_policy = nt.get_property_value('monitoring_policy') or 'noop'
@@ -104,6 +110,7 @@ def get_vdu_monitoring(template):
             if mon_policy != 'noop':
                 if 'parameters' in mon_policy:
                     mon_policy['monitoring_params'] = mon_policy['parameters']
+                monitoring_dict['vdus'] = {}
                 monitoring_dict['vdus'][nt.name] = {}
                 monitoring_dict['vdus'][nt.name][mon_policy['name']] = \
                     mon_policy
@@ -126,21 +133,21 @@ def get_mgmt_ports(tosca):
                 if vdu is not None:
                     name = 'mgmt_ip-%s' % vdu
                     mgmt_ports[name] = nt.name
-    LOG.debug('mgmt_ports: %s' % mgmt_ports)
+    LOG.debug('mgmt_ports: %s', mgmt_ports)
     return mgmt_ports
 
 
 @log.log
 def add_resources_tpl(heat_dict, hot_res_tpl):
-    for res, res_dict in hot_res_tpl.iteritems():
-        for vdu, vdu_dict in res_dict.iteritems():
+    for res, res_dict in iteritems(hot_res_tpl):
+        for vdu, vdu_dict in iteritems(res_dict):
             res_name = vdu + "_" + res
             heat_dict["resources"][res_name] = {
                 "type": HEAT_RESOURCE_MAP[res],
                 "properties": {}
             }
 
-            for prop, val in vdu_dict.iteritems():
+            for prop, val in iteritems(vdu_dict):
                 heat_dict["resources"][res_name]["properties"][prop] = val
             heat_dict["resources"][vdu]["properties"][res] = {
                 "get_resource": res_name
@@ -151,7 +158,7 @@ def add_resources_tpl(heat_dict, hot_res_tpl):
 def convert_unsupported_res_prop(heat_dict, unsupported_res_prop):
     res_dict = heat_dict['resources']
 
-    for res, attr in res_dict.iteritems():
+    for res, attr in iteritems(res_dict):
         res_type = attr['type']
         if res_type in unsupported_res_prop:
             prop_dict = attr['properties']
@@ -192,7 +199,7 @@ def post_process_heat_template(heat_tpl, mgmt_ports, res_tpl,
             heat_dict['outputs'].update(output)
         else:
             heat_dict['outputs'] = output
-        LOG.debug(_('Added output for %s') % outputname)
+        LOG.debug(_('Added output for %s'), outputname)
     add_resources_tpl(heat_dict, res_tpl)
     if unsupported_res_prop:
         convert_unsupported_res_prop(heat_dict, unsupported_res_prop)
@@ -225,6 +232,13 @@ def post_process_template(template):
                         nt.get_properties_objects().append(newprop)
                         nt.get_properties_objects().remove(p)
 
+        if nt.type in convert_prop_values:
+            for key in convert_prop_values[nt.type].keys():
+                for p in nt.get_properties_objects():
+                    if key == p.value:
+                        v = convert_prop_values[nt.type][p.value]
+                        p.value = v
+
 
 @log.log
 def get_mgmt_driver(template):
@@ -252,14 +266,14 @@ def get_flavor_dict(template, flavor_extra_input=None):
     flavor_dict = {}
     vdus = findvdus(template)
     for nt in vdus:
-        flavor_tmp = nt.get_properties().get('flavor', None)
+        flavor_tmp = nt.get_properties().get('flavor')
         if flavor_tmp:
             continue
-        if nt.get_capabilities().get("nfv_compute", None):
+        if nt.get_capabilities().get("nfv_compute"):
             flavor_dict[nt.name] = {}
             properties = nt.get_capabilities()["nfv_compute"].get_properties()
             for prop, (hot_prop, default, unit) in \
-                    FLAVOR_PROPS.iteritems():
+                    iteritems(FLAVOR_PROPS):
                 hot_prop_val = (properties[prop].value
                     if properties.get(prop, None) else None)
                 if unit and hot_prop_val:
@@ -284,25 +298,32 @@ def populate_flavor_extra_specs(es_dict, properties, flavor_extra_input):
             raise vnfm.HugePageSizeInvalidInput(
                 error_msg_details=(mval + ":Invalid Input"))
         es_dict['hw:mem_page_size'] = mval
+    if 'numa_nodes' in properties and 'numa_node_count' in properties:
+        LOG.warning(_('Both numa_nodes and numa_node_count have been'
+                      'specified; numa_node definitions will be ignored and'
+                      'numa_node_count will be applied'))
     if 'numa_node_count' in properties:
         es_dict['hw:numa_nodes'] = \
             properties['numa_node_count'].value
     if 'numa_nodes' in properties and 'numa_node_count' not in properties:
         nodes_dict = dict(properties['numa_nodes'].value)
         dval = list(nodes_dict.values())
+        ncount = 0
         for ndict in dval:
-            invalid_input = set(ndict.keys()) - {'id', 'vcpus', 'memory'}
+            invalid_input = set(ndict.keys()) - {'id', 'vcpus', 'mem_size'}
             if invalid_input:
                 raise vnfm.NumaNodesInvalidKeys(
                     error_msg_details=(', '.join(invalid_input)),
-                    valid_keys="id, vcpus and memory")
+                    valid_keys="id, vcpus and mem_size")
             if 'id' in ndict and 'vcpus' in ndict:
                 vk = "hw:numa_cpus." + str(ndict['id'])
                 vval = ",".join([str(x) for x in ndict['vcpus']])
                 es_dict[vk] = vval
-            if 'id' in ndict and 'memory' in ndict:
+            if 'id' in ndict and 'mem_size' in ndict:
                 mk = "hw:numa_mem." + str(ndict['id'])
-                es_dict[mk] = ndict['memory']
+                es_dict[mk] = ndict['mem_size']
+            ncount += 1
+        es_dict['hw:numa_nodes'] = ncount
     if 'cpu_allocation' in properties:
         cpu_dict = dict(properties['cpu_allocation'].value)
         invalid_input = set(cpu_dict.keys()) - CPU_PROP_KEY_SET
@@ -321,10 +342,10 @@ def get_image_dict(template):
     image_dict = {}
     vdus = findvdus(template)
     for vdu in vdus:
-        if not vdu.entity_tpl.get("artifacts", None):
+        if not vdu.entity_tpl.get("artifacts"):
             continue
         artifacts = vdu.entity_tpl["artifacts"]
-        for name, artifact in artifacts.iteritems():
+        for name, artifact in iteritems(artifacts):
             if ('type' in artifact.keys() and
               artifact["type"] == IMAGE):
                 if 'file' not in artifact.keys():
@@ -340,7 +361,7 @@ def get_image_dict(template):
 
 def get_resources_dict(template, flavor_extra_input=None):
     res_dict = dict()
-    for res, method in OS_RESOURCES.iteritems():
+    for res, method in iteritems(OS_RESOURCES):
         res_method = getattr(sys.modules[__name__], method)
         if res is 'flavor':
             res_dict[res] = res_method(template, flavor_extra_input)
