@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2011 OpenStack Foundation.
 # All Rights Reserved.
 #
@@ -32,6 +30,12 @@ from xml.parsers import expat
 import eventlet.wsgi
 # eventlet.patcher.monkey_patch(all=False, socket=True, thread=True)
 from oslo_config import cfg
+import oslo_i18n as i18n
+from oslo_log import log as logging
+from oslo_serialization import jsonutils
+from oslo_service import service as common_service
+from oslo_service import systemd
+from oslo_utils import excutils
 import routes.middleware
 import six
 import webob.dec
@@ -41,12 +45,7 @@ from tacker.common import constants
 from tacker.common import exceptions as exception
 from tacker import context
 from tacker.db import api
-from tacker.openstack.common import excutils
-from tacker.openstack.common import gettextutils
-from tacker.openstack.common import jsonutils
-from tacker.openstack.common import log as logging
-from tacker.openstack.common import service as common_service
-from tacker.openstack.common import systemd
+
 
 socket_opts = [
     cfg.IntOpt('backlog',
@@ -80,10 +79,14 @@ socket_opts = [
 CONF = cfg.CONF
 CONF.register_opts(socket_opts)
 
+
+def config_opts():
+    return [(None, socket_opts)]
+
 LOG = logging.getLogger(__name__)
 
 
-class WorkerService(object):
+class WorkerService(common_service.ServiceBase):
     """Wraps a worker to be handled by ProcessLauncher."""
 
     def __init__(self, service, application):
@@ -108,6 +111,9 @@ class WorkerService(object):
             self._server.kill()
             self._server = None
 
+    def reset(self):
+        pass
+
 
 class Server(object):
     """Server class to manage multiple WSGI sockets and applications."""
@@ -176,7 +182,6 @@ class Server(object):
                                        family=family)
                 if CONF.use_ssl:
                     sock = wrap_ssl(sock)
-
             except socket.error as err:
                 with excutils.save_and_reraise_exception() as ctxt:
                     if err.errno == errno.EADDRINUSE:
@@ -217,7 +222,8 @@ class Server(object):
         else:
             # Minimize the cost of checking for child exit by extending the
             # wait interval past the default of 0.01s.
-            self._launcher = common_service.ProcessLauncher(wait_interval=1.0)
+            self._launcher = common_service.ProcessLauncher(CONF,
+                                                            wait_interval=1.0)
             self._server = WorkerService(self, application)
             self._launcher.launch_service(self._server, workers=workers)
 
@@ -249,7 +255,7 @@ class Server(object):
     def _run(self, application, socket):
         """Start a WSGI server in a new green thread."""
         eventlet.wsgi.server(socket, application, custom_pool=self.pool,
-                             log=logging.WritableLogger(LOG))
+                             log=LOG)
 
 
 class Middleware(object):
@@ -358,7 +364,7 @@ class Request(webob.Request):
         """
         if not self.accept_language:
             return None
-        all_languages = gettextutils.get_available_languages('tacker')
+        all_languages = i18n.get_available_languages('tacker')
         return self.accept_language.best_match(all_languages)
 
     @property
@@ -431,13 +437,13 @@ class XMLDictSerializer(DictSerializer):
                 root_key = constants.VIRTUAL_ROOT_KEY
                 root_value = None
             else:
-                link_keys = [k for k in data.iterkeys() or []
+                link_keys = [k for k in data or []
                              if k.endswith('_links')]
                 if link_keys:
                     links = data.pop(link_keys[0], None)
                     has_atom = True
                 root_key = (len(data) == 1 and
-                            data.keys()[0] or constants.VIRTUAL_ROOT_KEY)
+                            list(data.keys())[0] or constants.VIRTUAL_ROOT_KEY)
                 root_value = data.get(root_key, data)
             doc = etree.Element("_temp_root")
             used_prefixes = []
@@ -951,7 +957,7 @@ class Debug(Middleware):
         resp = req.get_response(self.application)
 
         print(("*" * 40) + " RESPONSE HEADERS")
-        for (key, value) in resp.headers.iteritems():
+        for (key, value) in six.iteritems(resp.headers):
             print(key, "=", value)
         print()
 
@@ -1026,7 +1032,7 @@ class Router(object):
         if not match:
             language = req.best_match_language()
             msg = _('The resource could not be found.')
-            msg = gettextutils.translate(msg, language)
+            msg = i18n.translate(msg, language)
             return webob.exc.HTTPNotFound(explanation=msg)
         app = match['controller']
         return app
